Class: Aws::RedshiftServerless::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::RedshiftServerless::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-redshiftserverless/client.rb,
sig/client.rbs
Overview
An API client for RedshiftServerless. To construct a client, you need to configure a :region and :credentials.
client = Aws::RedshiftServerless::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _ConvertRecoveryPointToSnapshotResponseSuccess, _CreateCustomDomainAssociationResponseSuccess, _CreateEndpointAccessResponseSuccess, _CreateNamespaceResponseSuccess, _CreateReservationResponseSuccess, _CreateScheduledActionResponseSuccess, _CreateSnapshotCopyConfigurationResponseSuccess, _CreateSnapshotResponseSuccess, _CreateUsageLimitResponseSuccess, _CreateWorkgroupResponseSuccess, _DeleteCustomDomainAssociationResponseSuccess, _DeleteEndpointAccessResponseSuccess, _DeleteNamespaceResponseSuccess, _DeleteResourcePolicyResponseSuccess, _DeleteScheduledActionResponseSuccess, _DeleteSnapshotCopyConfigurationResponseSuccess, _DeleteSnapshotResponseSuccess, _DeleteUsageLimitResponseSuccess, _DeleteWorkgroupResponseSuccess, _GetCredentialsResponseSuccess, _GetCustomDomainAssociationResponseSuccess, _GetEndpointAccessResponseSuccess, _GetIdentityCenterAuthTokenResponseSuccess, _GetNamespaceResponseSuccess, _GetRecoveryPointResponseSuccess, _GetReservationOfferingResponseSuccess, _GetReservationResponseSuccess, _GetResourcePolicyResponseSuccess, _GetScheduledActionResponseSuccess, _GetSnapshotResponseSuccess, _GetTableRestoreStatusResponseSuccess, _GetTrackResponseSuccess, _GetUsageLimitResponseSuccess, _GetWorkgroupResponseSuccess, _ListCustomDomainAssociationsResponseSuccess, _ListEndpointAccessResponseSuccess, _ListManagedWorkgroupsResponseSuccess, _ListNamespacesResponseSuccess, _ListRecoveryPointsResponseSuccess, _ListReservationOfferingsResponseSuccess, _ListReservationsResponseSuccess, _ListScheduledActionsResponseSuccess, _ListSnapshotCopyConfigurationsResponseSuccess, _ListSnapshotsResponseSuccess, _ListTableRestoreStatusResponseSuccess, _ListTagsForResourceResponseSuccess, _ListTracksResponseSuccess, _ListUsageLimitsResponseSuccess, _ListWorkgroupsResponseSuccess, _PutResourcePolicyResponseSuccess, _RestoreFromRecoveryPointResponseSuccess, _RestoreFromSnapshotResponseSuccess, _RestoreTableFromRecoveryPointResponseSuccess, _RestoreTableFromSnapshotResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateCustomDomainAssociationResponseSuccess, _UpdateEndpointAccessResponseSuccess, _UpdateLakehouseConfigurationResponseSuccess, _UpdateNamespaceResponseSuccess, _UpdateScheduledActionResponseSuccess, _UpdateSnapshotCopyConfigurationResponseSuccess, _UpdateSnapshotResponseSuccess, _UpdateUsageLimitResponseSuccess, _UpdateWorkgroupResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#convert_recovery_point_to_snapshot(params = {}) ⇒ Types::ConvertRecoveryPointToSnapshotResponse
Converts a recovery point to a snapshot.
-
#create_custom_domain_association(params = {}) ⇒ Types::CreateCustomDomainAssociationResponse
Creates a custom domain association for Amazon Redshift Serverless.
-
#create_endpoint_access(params = {}) ⇒ Types::CreateEndpointAccessResponse
Creates an Amazon Redshift Serverless managed VPC endpoint.
-
#create_namespace(params = {}) ⇒ Types::CreateNamespaceResponse
Creates a namespace in Amazon Redshift Serverless.
-
#create_reservation(params = {}) ⇒ Types::CreateReservationResponse
Creates an Amazon Redshift Serverless reservation, which gives you the option to commit to a specified number of Redshift Processing Units (RPUs) for a year at a discount from Serverless on-demand (OD) rates.
-
#create_scheduled_action(params = {}) ⇒ Types::CreateScheduledActionResponse
Creates a scheduled action.
-
#create_snapshot(params = {}) ⇒ Types::CreateSnapshotResponse
Creates a snapshot of all databases in a namespace.
-
#create_snapshot_copy_configuration(params = {}) ⇒ Types::CreateSnapshotCopyConfigurationResponse
Creates a snapshot copy configuration that lets you copy snapshots to another Amazon Web Services Region.
-
#create_usage_limit(params = {}) ⇒ Types::CreateUsageLimitResponse
Creates a usage limit for a specified Amazon Redshift Serverless usage type.
-
#create_workgroup(params = {}) ⇒ Types::CreateWorkgroupResponse
Creates an workgroup in Amazon Redshift Serverless.
-
#delete_custom_domain_association(params = {}) ⇒ Struct
Deletes a custom domain association for Amazon Redshift Serverless.
-
#delete_endpoint_access(params = {}) ⇒ Types::DeleteEndpointAccessResponse
Deletes an Amazon Redshift Serverless managed VPC endpoint.
-
#delete_namespace(params = {}) ⇒ Types::DeleteNamespaceResponse
Deletes a namespace from Amazon Redshift Serverless.
-
#delete_resource_policy(params = {}) ⇒ Struct
Deletes the specified resource policy.
-
#delete_scheduled_action(params = {}) ⇒ Types::DeleteScheduledActionResponse
Deletes a scheduled action.
-
#delete_snapshot(params = {}) ⇒ Types::DeleteSnapshotResponse
Deletes a snapshot from Amazon Redshift Serverless.
-
#delete_snapshot_copy_configuration(params = {}) ⇒ Types::DeleteSnapshotCopyConfigurationResponse
Deletes a snapshot copy configuration.
-
#delete_usage_limit(params = {}) ⇒ Types::DeleteUsageLimitResponse
Deletes a usage limit from Amazon Redshift Serverless.
-
#delete_workgroup(params = {}) ⇒ Types::DeleteWorkgroupResponse
Deletes a workgroup.
-
#get_credentials(params = {}) ⇒ Types::GetCredentialsResponse
Returns a database user name and temporary password with temporary authorization to log in to Amazon Redshift Serverless.
-
#get_custom_domain_association(params = {}) ⇒ Types::GetCustomDomainAssociationResponse
Gets information about a specific custom domain association.
-
#get_endpoint_access(params = {}) ⇒ Types::GetEndpointAccessResponse
Returns information, such as the name, about a VPC endpoint.
-
#get_identity_center_auth_token(params = {}) ⇒ Types::GetIdentityCenterAuthTokenResponse
Returns an Identity Center authentication token for accessing Amazon Redshift Serverless workgroups.
-
#get_namespace(params = {}) ⇒ Types::GetNamespaceResponse
Returns information about a namespace in Amazon Redshift Serverless.
-
#get_recovery_point(params = {}) ⇒ Types::GetRecoveryPointResponse
Returns information about a recovery point.
-
#get_reservation(params = {}) ⇒ Types::GetReservationResponse
Gets an Amazon Redshift Serverless reservation.
-
#get_reservation_offering(params = {}) ⇒ Types::GetReservationOfferingResponse
Returns the reservation offering.
-
#get_resource_policy(params = {}) ⇒ Types::GetResourcePolicyResponse
Returns a resource policy.
-
#get_scheduled_action(params = {}) ⇒ Types::GetScheduledActionResponse
Returns information about a scheduled action.
-
#get_snapshot(params = {}) ⇒ Types::GetSnapshotResponse
Returns information about a specific snapshot.
-
#get_table_restore_status(params = {}) ⇒ Types::GetTableRestoreStatusResponse
Returns information about a
TableRestoreStatusobject. -
#get_track(params = {}) ⇒ Types::GetTrackResponse
Get the Redshift Serverless version for a specified track.
-
#get_usage_limit(params = {}) ⇒ Types::GetUsageLimitResponse
Returns information about a usage limit.
-
#get_workgroup(params = {}) ⇒ Types::GetWorkgroupResponse
Returns information about a specific workgroup.
-
#list_custom_domain_associations(params = {}) ⇒ Types::ListCustomDomainAssociationsResponse
Lists custom domain associations for Amazon Redshift Serverless.
-
#list_endpoint_access(params = {}) ⇒ Types::ListEndpointAccessResponse
Returns an array of
EndpointAccessobjects and relevant information. -
#list_managed_workgroups(params = {}) ⇒ Types::ListManagedWorkgroupsResponse
Returns information about a list of specified managed workgroups in your account.
-
#list_namespaces(params = {}) ⇒ Types::ListNamespacesResponse
Returns information about a list of specified namespaces.
-
#list_recovery_points(params = {}) ⇒ Types::ListRecoveryPointsResponse
Returns an array of recovery points.
-
#list_reservation_offerings(params = {}) ⇒ Types::ListReservationOfferingsResponse
Returns the current reservation offerings in your account.
-
#list_reservations(params = {}) ⇒ Types::ListReservationsResponse
Returns a list of Reservation objects.
-
#list_scheduled_actions(params = {}) ⇒ Types::ListScheduledActionsResponse
Returns a list of scheduled actions.
-
#list_snapshot_copy_configurations(params = {}) ⇒ Types::ListSnapshotCopyConfigurationsResponse
Returns a list of snapshot copy configurations.
-
#list_snapshots(params = {}) ⇒ Types::ListSnapshotsResponse
Returns a list of snapshots.
-
#list_table_restore_status(params = {}) ⇒ Types::ListTableRestoreStatusResponse
Returns information about an array of
TableRestoreStatusobjects. -
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags assigned to a resource.
-
#list_tracks(params = {}) ⇒ Types::ListTracksResponse
List the Amazon Redshift Serverless versions.
-
#list_usage_limits(params = {}) ⇒ Types::ListUsageLimitsResponse
Lists all usage limits within Amazon Redshift Serverless.
-
#list_workgroups(params = {}) ⇒ Types::ListWorkgroupsResponse
Returns information about a list of specified workgroups.
-
#put_resource_policy(params = {}) ⇒ Types::PutResourcePolicyResponse
Creates or updates a resource policy.
-
#restore_from_recovery_point(params = {}) ⇒ Types::RestoreFromRecoveryPointResponse
Restore the data from a recovery point.
-
#restore_from_snapshot(params = {}) ⇒ Types::RestoreFromSnapshotResponse
Restores a namespace from a snapshot.
-
#restore_table_from_recovery_point(params = {}) ⇒ Types::RestoreTableFromRecoveryPointResponse
Restores a table from a recovery point to your Amazon Redshift Serverless instance.
-
#restore_table_from_snapshot(params = {}) ⇒ Types::RestoreTableFromSnapshotResponse
Restores a table from a snapshot to your Amazon Redshift Serverless instance.
-
#tag_resource(params = {}) ⇒ Struct
Assigns one or more tags to a resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes a tag or set of tags from a resource.
-
#update_custom_domain_association(params = {}) ⇒ Types::UpdateCustomDomainAssociationResponse
Updates an Amazon Redshift Serverless certificate associated with a custom domain.
-
#update_endpoint_access(params = {}) ⇒ Types::UpdateEndpointAccessResponse
Updates an Amazon Redshift Serverless managed endpoint.
-
#update_lakehouse_configuration(params = {}) ⇒ Types::UpdateLakehouseConfigurationResponse
Modifies the lakehouse configuration for a namespace.
-
#update_namespace(params = {}) ⇒ Types::UpdateNamespaceResponse
Updates a namespace with the specified settings.
-
#update_scheduled_action(params = {}) ⇒ Types::UpdateScheduledActionResponse
Updates a scheduled action.
-
#update_snapshot(params = {}) ⇒ Types::UpdateSnapshotResponse
Updates a snapshot.
-
#update_snapshot_copy_configuration(params = {}) ⇒ Types::UpdateSnapshotCopyConfigurationResponse
Updates a snapshot copy configuration.
-
#update_usage_limit(params = {}) ⇒ Types::UpdateUsageLimitResponse
Update a usage limit in Amazon Redshift Serverless.
-
#update_workgroup(params = {}) ⇒ Types::UpdateWorkgroupResponse
Updates a workgroup with the specified configuration settings.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
478 479 480 |
# File 'lib/aws-sdk-redshiftserverless/client.rb', line 478 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4403 4404 4405 |
# File 'lib/aws-sdk-redshiftserverless/client.rb', line 4403 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4406 4407 4408 |
# File 'lib/aws-sdk-redshiftserverless/client.rb', line 4406 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4376 4377 4378 4379 4380 4381 4382 4383 4384 4385 4386 4387 4388 4389 4390 4391 4392 |
# File 'lib/aws-sdk-redshiftserverless/client.rb', line 4376 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::RedshiftServerless') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-redshiftserverless' context[:gem_version] = '1.70.0' Seahorse::Client::Request.new(handlers, context) end |
#convert_recovery_point_to_snapshot(params = {}) ⇒ Types::ConvertRecoveryPointToSnapshotResponse
Converts a recovery point to a snapshot. For more information about recovery points and snapshots, see Working with snapshots and recovery points.
87 |
# File 'sig/client.rbs', line 87
def convert_recovery_point_to_snapshot: (
|
#create_custom_domain_association(params = {}) ⇒ Types::CreateCustomDomainAssociationResponse
Creates a custom domain association for Amazon Redshift Serverless.
108 |
# File 'sig/client.rbs', line 108
def create_custom_domain_association: (
|
#create_endpoint_access(params = {}) ⇒ Types::CreateEndpointAccessResponse
Creates an Amazon Redshift Serverless managed VPC endpoint.
120 |
# File 'sig/client.rbs', line 120
def create_endpoint_access: (
|
#create_namespace(params = {}) ⇒ Types::CreateNamespaceResponse
Creates a namespace in Amazon Redshift Serverless.
134 |
# File 'sig/client.rbs', line 134
def create_namespace: (
|
#create_reservation(params = {}) ⇒ Types::CreateReservationResponse
Creates an Amazon Redshift Serverless reservation, which gives you the option to commit to a specified number of Redshift Processing Units (RPUs) for a year at a discount from Serverless on-demand (OD) rates.
160 |
# File 'sig/client.rbs', line 160
def create_reservation: (
|
#create_scheduled_action(params = {}) ⇒ Types::CreateScheduledActionResponse
Creates a scheduled action. A scheduled action contains a schedule and
an Amazon Redshift API action. For example, you can create a schedule
of when to run the CreateSnapshot API operation.
172 |
# File 'sig/client.rbs', line 172
def create_scheduled_action: (
|
#create_snapshot(params = {}) ⇒ Types::CreateSnapshotResponse
Creates a snapshot of all databases in a namespace. For more information about snapshots, see Working with snapshots and recovery points.
193 |
# File 'sig/client.rbs', line 193
def create_snapshot: (
|
#create_snapshot_copy_configuration(params = {}) ⇒ Types::CreateSnapshotCopyConfigurationResponse
Creates a snapshot copy configuration that lets you copy snapshots to another Amazon Web Services Region.
211 |
# File 'sig/client.rbs', line 211
def create_snapshot_copy_configuration: (
|
#create_usage_limit(params = {}) ⇒ Types::CreateUsageLimitResponse
Creates a usage limit for a specified Amazon Redshift Serverless usage type. The usage limit is identified by the returned usage limit identifier.
224 |
# File 'sig/client.rbs', line 224
def create_usage_limit: (
|
#create_workgroup(params = {}) ⇒ Types::CreateWorkgroupResponse
Creates an workgroup in Amazon Redshift Serverless.
VPC Block Public Access (BPA) enables you to block resources in VPCs and subnets that you own in a Region from reaching or being reached from the internet through internet gateways and egress-only internet gateways. If a workgroup is in an account with VPC BPA turned on, the following capabilities are blocked:
-
Creating a public access workgroup
-
Modifying a private workgroup to public
-
Adding a subnet with VPC BPA turned on to the workgroup when the workgroup is public
For more information about VPC BPA, see Block public access to VPCs and subnets in the Amazon VPC User Guide.
238 |
# File 'sig/client.rbs', line 238
def create_workgroup: (
|
#delete_custom_domain_association(params = {}) ⇒ Struct
Deletes a custom domain association for Amazon Redshift Serverless.
274 |
# File 'sig/client.rbs', line 274
def delete_custom_domain_association: (
|
#delete_endpoint_access(params = {}) ⇒ Types::DeleteEndpointAccessResponse
Deletes an Amazon Redshift Serverless managed VPC endpoint.
285 |
# File 'sig/client.rbs', line 285
def delete_endpoint_access: (
|
#delete_namespace(params = {}) ⇒ Types::DeleteNamespaceResponse
Deletes a namespace from Amazon Redshift Serverless. Before you delete the namespace, you can create a final snapshot that has all of the data within the namespace.
295 |
# File 'sig/client.rbs', line 295
def delete_namespace: (
|
#delete_resource_policy(params = {}) ⇒ Struct
Deletes the specified resource policy.
306 |
# File 'sig/client.rbs', line 306
def delete_resource_policy: (
|
#delete_scheduled_action(params = {}) ⇒ Types::DeleteScheduledActionResponse
Deletes a scheduled action.
316 |
# File 'sig/client.rbs', line 316
def delete_scheduled_action: (
|
#delete_snapshot(params = {}) ⇒ Types::DeleteSnapshotResponse
Deletes a snapshot from Amazon Redshift Serverless.
326 |
# File 'sig/client.rbs', line 326
def delete_snapshot: (
|
#delete_snapshot_copy_configuration(params = {}) ⇒ Types::DeleteSnapshotCopyConfigurationResponse
Deletes a snapshot copy configuration
336 |
# File 'sig/client.rbs', line 336
def delete_snapshot_copy_configuration: (
|
#delete_usage_limit(params = {}) ⇒ Types::DeleteUsageLimitResponse
Deletes a usage limit from Amazon Redshift Serverless.
346 |
# File 'sig/client.rbs', line 346
def delete_usage_limit: (
|
#delete_workgroup(params = {}) ⇒ Types::DeleteWorkgroupResponse
Deletes a workgroup.
356 |
# File 'sig/client.rbs', line 356
def delete_workgroup: (
|
#get_credentials(params = {}) ⇒ Types::GetCredentialsResponse
Returns a database user name and temporary password with temporary authorization to log in to Amazon Redshift Serverless.
By default, the temporary credentials expire in 900 seconds. You can optionally specify a duration between 900 seconds (15 minutes) and 3600 seconds (60 minutes).
The Identity and Access Management (IAM) user or role that runs GetCredentials must have an IAM policy attached that allows access to all necessary actions and resources.
If the DbName parameter is specified, the IAM policy must allow
access to the resource dbname for the specified database name.
369 |
# File 'sig/client.rbs', line 369
def get_credentials: (
|
#get_custom_domain_association(params = {}) ⇒ Types::GetCustomDomainAssociationResponse
Gets information about a specific custom domain association.
385 |
# File 'sig/client.rbs', line 385
def get_custom_domain_association: (
|
#get_endpoint_access(params = {}) ⇒ Types::GetEndpointAccessResponse
Returns information, such as the name, about a VPC endpoint.
396 |
# File 'sig/client.rbs', line 396
def get_endpoint_access: (
|
#get_identity_center_auth_token(params = {}) ⇒ Types::GetIdentityCenterAuthTokenResponse
Returns an Identity Center authentication token for accessing Amazon Redshift Serverless workgroups.
The token provides secure access to data within the specified workgroups using Identity Center identity propagation. The token expires after a specified duration and must be refreshed for continued access.
The Identity and Access Management (IAM) user or role that runs GetIdentityCenterAuthToken must have appropriate permissions to access the specified workgroups and Identity Center integration must be configured for the workgroups.
407 |
# File 'sig/client.rbs', line 407
def get_identity_center_auth_token: (
|
#get_namespace(params = {}) ⇒ Types::GetNamespaceResponse
Returns information about a namespace in Amazon Redshift Serverless.
417 |
# File 'sig/client.rbs', line 417
def get_namespace: (
|
#get_recovery_point(params = {}) ⇒ Types::GetRecoveryPointResponse
Returns information about a recovery point.
427 |
# File 'sig/client.rbs', line 427
def get_recovery_point: (
|
#get_reservation(params = {}) ⇒ Types::GetReservationResponse
Gets an Amazon Redshift Serverless reservation. A reservation gives you the option to commit to a specified number of Redshift Processing Units (RPUs) for a year at a discount from Serverless on-demand (OD) rates.
437 |
# File 'sig/client.rbs', line 437
def get_reservation: (
|
#get_reservation_offering(params = {}) ⇒ Types::GetReservationOfferingResponse
Returns the reservation offering. The offering determines the payment schedule for the reservation.
447 |
# File 'sig/client.rbs', line 447
def get_reservation_offering: (
|
#get_resource_policy(params = {}) ⇒ Types::GetResourcePolicyResponse
Returns a resource policy.
457 |
# File 'sig/client.rbs', line 457
def get_resource_policy: (
|
#get_scheduled_action(params = {}) ⇒ Types::GetScheduledActionResponse
Returns information about a scheduled action.
467 |
# File 'sig/client.rbs', line 467
def get_scheduled_action: (
|
#get_snapshot(params = {}) ⇒ Types::GetSnapshotResponse
Returns information about a specific snapshot.
477 |
# File 'sig/client.rbs', line 477
def get_snapshot: (
|
#get_table_restore_status(params = {}) ⇒ Types::GetTableRestoreStatusResponse
Returns information about a TableRestoreStatus object.
489 |
# File 'sig/client.rbs', line 489
def get_table_restore_status: (
|
#get_track(params = {}) ⇒ Types::GetTrackResponse
Get the Redshift Serverless version for a specified track.
499 |
# File 'sig/client.rbs', line 499
def get_track: (
|
#get_usage_limit(params = {}) ⇒ Types::GetUsageLimitResponse
Returns information about a usage limit.
509 |
# File 'sig/client.rbs', line 509
def get_usage_limit: (
|
#get_workgroup(params = {}) ⇒ Types::GetWorkgroupResponse
Returns information about a specific workgroup.
519 |
# File 'sig/client.rbs', line 519
def get_workgroup: (
|
#list_custom_domain_associations(params = {}) ⇒ Types::ListCustomDomainAssociationsResponse
Lists custom domain associations for Amazon Redshift Serverless.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
530 |
# File 'sig/client.rbs', line 530
def list_custom_domain_associations: (
|
#list_endpoint_access(params = {}) ⇒ Types::ListEndpointAccessResponse
Returns an array of EndpointAccess objects and relevant information.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
544 |
# File 'sig/client.rbs', line 544
def list_endpoint_access: (
|
#list_managed_workgroups(params = {}) ⇒ Types::ListManagedWorkgroupsResponse
Returns information about a list of specified managed workgroups in your account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
559 |
# File 'sig/client.rbs', line 559
def list_managed_workgroups: (
|
#list_namespaces(params = {}) ⇒ Types::ListNamespacesResponse
Returns information about a list of specified namespaces.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
572 |
# File 'sig/client.rbs', line 572
def list_namespaces: (
|
#list_recovery_points(params = {}) ⇒ Types::ListRecoveryPointsResponse
Returns an array of recovery points.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
584 |
# File 'sig/client.rbs', line 584
def list_recovery_points: (
|
#list_reservation_offerings(params = {}) ⇒ Types::ListReservationOfferingsResponse
Returns the current reservation offerings in your account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
600 |
# File 'sig/client.rbs', line 600
def list_reservation_offerings: (
|
#list_reservations(params = {}) ⇒ Types::ListReservationsResponse
Returns a list of Reservation objects.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
612 |
# File 'sig/client.rbs', line 612
def list_reservations: (
|
#list_scheduled_actions(params = {}) ⇒ Types::ListScheduledActionsResponse
Returns a list of scheduled actions. You can use the flags to filter the list of returned scheduled actions.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
624 |
# File 'sig/client.rbs', line 624
def list_scheduled_actions: (
|
#list_snapshot_copy_configurations(params = {}) ⇒ Types::ListSnapshotCopyConfigurationsResponse
Returns a list of snapshot copy configurations.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
637 |
# File 'sig/client.rbs', line 637
def list_snapshot_copy_configurations: (
|
#list_snapshots(params = {}) ⇒ Types::ListSnapshotsResponse
Returns a list of snapshots.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
650 |
# File 'sig/client.rbs', line 650
def list_snapshots: (
|
#list_table_restore_status(params = {}) ⇒ Types::ListTableRestoreStatusResponse
Returns information about an array of TableRestoreStatus objects.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
667 |
# File 'sig/client.rbs', line 667
def list_table_restore_status: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags assigned to a resource.
680 |
# File 'sig/client.rbs', line 680
def list_tags_for_resource: (
|
#list_tracks(params = {}) ⇒ Types::ListTracksResponse
List the Amazon Redshift Serverless versions.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
691 |
# File 'sig/client.rbs', line 691
def list_tracks: (
|
#list_usage_limits(params = {}) ⇒ Types::ListUsageLimitsResponse
Lists all usage limits within Amazon Redshift Serverless.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
703 |
# File 'sig/client.rbs', line 703
def list_usage_limits: (
|
#list_workgroups(params = {}) ⇒ Types::ListWorkgroupsResponse
Returns information about a list of specified workgroups.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
717 |
# File 'sig/client.rbs', line 717
def list_workgroups: (
|
#put_resource_policy(params = {}) ⇒ Types::PutResourcePolicyResponse
Creates or updates a resource policy. Currently, you can use policies to share snapshots across Amazon Web Services accounts.
729 |
# File 'sig/client.rbs', line 729
def put_resource_policy: (
|
#restore_from_recovery_point(params = {}) ⇒ Types::RestoreFromRecoveryPointResponse
Restore the data from a recovery point.
741 |
# File 'sig/client.rbs', line 741
def restore_from_recovery_point: (
|
#restore_from_snapshot(params = {}) ⇒ Types::RestoreFromSnapshotResponse
Restores a namespace from a snapshot.
755 |
# File 'sig/client.rbs', line 755
def restore_from_snapshot: (
|
#restore_table_from_recovery_point(params = {}) ⇒ Types::RestoreTableFromRecoveryPointResponse
Restores a table from a recovery point to your Amazon Redshift Serverless instance. You can't use this operation to restore tables with interleaved sort keys.
771 |
# File 'sig/client.rbs', line 771
def restore_table_from_recovery_point: (
|
#restore_table_from_snapshot(params = {}) ⇒ Types::RestoreTableFromSnapshotResponse
Restores a table from a snapshot to your Amazon Redshift Serverless instance. You can't use this operation to restore tables with interleaved sort keys.
790 |
# File 'sig/client.rbs', line 790
def restore_table_from_snapshot: (
|
#tag_resource(params = {}) ⇒ Struct
Assigns one or more tags to a resource.
808 |
# File 'sig/client.rbs', line 808
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Removes a tag or set of tags from a resource.
823 |
# File 'sig/client.rbs', line 823
def untag_resource: (
|
#update_custom_domain_association(params = {}) ⇒ Types::UpdateCustomDomainAssociationResponse
Updates an Amazon Redshift Serverless certificate associated with a custom domain.
837 |
# File 'sig/client.rbs', line 837
def update_custom_domain_association: (
|
#update_endpoint_access(params = {}) ⇒ Types::UpdateEndpointAccessResponse
Updates an Amazon Redshift Serverless managed endpoint.
849 |
# File 'sig/client.rbs', line 849
def update_endpoint_access: (
|
#update_lakehouse_configuration(params = {}) ⇒ Types::UpdateLakehouseConfigurationResponse
Modifies the lakehouse configuration for a namespace. This operation allows you to manage Amazon Redshift federated permissions and Amazon Web Services IAM Identity Center trusted identity propagation.
863 |
# File 'sig/client.rbs', line 863
def update_lakehouse_configuration: (
|
#update_namespace(params = {}) ⇒ Types::UpdateNamespaceResponse
Updates a namespace with the specified settings. Unless required, you
can't update multiple parameters in one request. For example, you
must specify both adminUsername and adminUserPassword to update
either field, but you can't update both kmsKeyId and logExports
in a single request.
878 |
# File 'sig/client.rbs', line 878
def update_namespace: (
|
#update_scheduled_action(params = {}) ⇒ Types::UpdateScheduledActionResponse
Updates a scheduled action.
896 |
# File 'sig/client.rbs', line 896
def update_scheduled_action: (
|
#update_snapshot(params = {}) ⇒ Types::UpdateSnapshotResponse
Updates a snapshot.
916 |
# File 'sig/client.rbs', line 916
def update_snapshot: (
|
#update_snapshot_copy_configuration(params = {}) ⇒ Types::UpdateSnapshotCopyConfigurationResponse
Updates a snapshot copy configuration.
927 |
# File 'sig/client.rbs', line 927
def update_snapshot_copy_configuration: (
|
#update_usage_limit(params = {}) ⇒ Types::UpdateUsageLimitResponse
Update a usage limit in Amazon Redshift Serverless. You can't update the usage type or period of a usage limit.
938 |
# File 'sig/client.rbs', line 938
def update_usage_limit: (
|
#update_workgroup(params = {}) ⇒ Types::UpdateWorkgroupResponse
Updates a workgroup with the specified configuration settings. You
can't update multiple parameters in one request. For example, you can
update baseCapacity or port in a single request, but you can't
update both in the same request.
VPC Block Public Access (BPA) enables you to block resources in VPCs and subnets that you own in a Region from reaching or being reached from the internet through internet gateways and egress-only internet gateways. If a workgroup is in an account with VPC BPA turned on, the following capabilities are blocked:
-
Creating a public access workgroup
-
Modifying a private workgroup to public
-
Adding a subnet with VPC BPA turned on to the workgroup when the workgroup is public
For more information about VPC BPA, see Block public access to VPCs and subnets in the Amazon VPC User Guide.
950 |
# File 'sig/client.rbs', line 950
def update_workgroup: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4396 4397 4398 |
# File 'lib/aws-sdk-redshiftserverless/client.rb', line 4396 def waiter_names [] end |