Class: Aws::RedshiftServerless::Types::ConfigParameter
- Inherits:
-
Struct
- Object
- Struct
- Aws::RedshiftServerless::Types::ConfigParameter
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-redshiftserverless/types.rb
Overview
An array of key-value pairs to set for advanced control over Amazon Redshift Serverless.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#parameter_key ⇒ String
The key of the parameter.
-
#parameter_value ⇒ String
The value of the parameter to set.
Instance Attribute Details
#parameter_key ⇒ String
The key of the parameter. The options are auto_mv, datestyle,
enable_case_sensitive_identifier, enable_user_activity_logging,
query_group, search_path, require_ssl, use_fips_ssl, and
either wlm_json_configuration or query monitoring metrics that let
you define performance boundaries. You can either specify individual
query monitoring metrics (such as max_scan_row_count,
max_query_execution_time) or use wlm_json_configuration to
define query queues with rules, but not both. If you're using
wlm_json_configuration, the maximum size of parameterValue is
8000 characters. For more information about query monitoring rules
and available metrics, see Query monitoring metrics for Amazon
Redshift Serverless.
87 88 89 90 91 92 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 87 class ConfigParameter < Struct.new( :parameter_key, :parameter_value) SENSITIVE = [] include Aws::Structure end |
#parameter_value ⇒ String
The value of the parameter to set.
87 88 89 90 91 92 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 87 class ConfigParameter < Struct.new( :parameter_key, :parameter_value) SENSITIVE = [] include Aws::Structure end |