Class: Aws::RedshiftServerless::Types::CreateSnapshotScheduleActionParameters

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-redshiftserverless/types.rb

Overview

The parameters that you can use to configure a scheduled action to create a snapshot. For more information about creating a scheduled action, see CreateScheduledAction.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#namespace_nameString

The name of the namespace for which you want to configure a scheduled action to create a snapshot.

Returns:

  • (String)


613
614
615
616
617
618
619
620
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 613

class CreateSnapshotScheduleActionParameters < Struct.new(
  :namespace_name,
  :retention_period,
  :snapshot_name_prefix,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#retention_periodInteger

The retention period of the snapshot created by the scheduled action.

Returns:

  • (Integer)


613
614
615
616
617
618
619
620
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 613

class CreateSnapshotScheduleActionParameters < Struct.new(
  :namespace_name,
  :retention_period,
  :snapshot_name_prefix,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#snapshot_name_prefixString

A string prefix that is attached to the name of the snapshot created by the scheduled action. The final name of the snapshot is the string prefix appended by the date and time of when the snapshot was created.

Returns:

  • (String)


613
614
615
616
617
618
619
620
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 613

class CreateSnapshotScheduleActionParameters < Struct.new(
  :namespace_name,
  :retention_period,
  :snapshot_name_prefix,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

An array of Tag objects to associate with the snapshot.

Returns:



613
614
615
616
617
618
619
620
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 613

class CreateSnapshotScheduleActionParameters < Struct.new(
  :namespace_name,
  :retention_period,
  :snapshot_name_prefix,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end