Class: Aws::RedshiftServerless::Types::GetCredentialsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::RedshiftServerless::Types::GetCredentialsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-redshiftserverless/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:db_password, :db_user]
Instance Attribute Summary collapse
-
#db_password ⇒ String
A temporary password that authorizes the user name returned by
DbUserto log on to the databaseDbName. -
#db_user ⇒ String
A database user name that is authorized to log on to the database
DbNameusing the passwordDbPassword. -
#expiration ⇒ Time
The date and time the password in
DbPasswordexpires. -
#next_refresh_time ⇒ Time
The date and time of when the
DbUserandDbPasswordauthorization refreshes.
Instance Attribute Details
#db_password ⇒ String
A temporary password that authorizes the user name returned by DbUser to log on to the database DbName.
1183 1184 1185 1186 1187 1188 1189 1190 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 1183 class GetCredentialsResponse < Struct.new( :db_password, :db_user, :expiration, :next_refresh_time) SENSITIVE = [:db_password, :db_user] include Aws::Structure end |
#db_user ⇒ String
A database user name that is authorized to log on to the database DbName using the password DbPassword. If the specified DbUser exists in the database, the new user name has the same database privileges as the the user named in DbUser. By default, the user is added to PUBLIC.
1183 1184 1185 1186 1187 1188 1189 1190 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 1183 class GetCredentialsResponse < Struct.new( :db_password, :db_user, :expiration, :next_refresh_time) SENSITIVE = [:db_password, :db_user] include Aws::Structure end |
#expiration ⇒ Time
The date and time the password in DbPassword expires.
1183 1184 1185 1186 1187 1188 1189 1190 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 1183 class GetCredentialsResponse < Struct.new( :db_password, :db_user, :expiration, :next_refresh_time) SENSITIVE = [:db_password, :db_user] include Aws::Structure end |
#next_refresh_time ⇒ Time
The date and time of when the DbUser and DbPassword authorization refreshes.
1183 1184 1185 1186 1187 1188 1189 1190 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 1183 class GetCredentialsResponse < Struct.new( :db_password, :db_user, :expiration, :next_refresh_time) SENSITIVE = [:db_password, :db_user] include Aws::Structure end |