Class: Aws::RedshiftServerless::Types::ListCustomDomainAssociationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::RedshiftServerless::Types::ListCustomDomainAssociationsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-redshiftserverless/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#custom_domain_certificate_arn ⇒ String
The custom domain name’s certificate Amazon resource name (ARN).
-
#custom_domain_name ⇒ String
The custom domain name associated with the workgroup.
-
#max_results ⇒ Integer
An optional parameter that specifies the maximum number of results to return.
-
#next_token ⇒ String
When
nextTokenis returned, there are more results available.
Instance Attribute Details
#custom_domain_certificate_arn ⇒ String
The custom domain name’s certificate Amazon resource name (ARN).
1666 1667 1668 1669 1670 1671 1672 1673 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 1666 class ListCustomDomainAssociationsRequest < Struct.new( :custom_domain_certificate_arn, :custom_domain_name, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#custom_domain_name ⇒ String
The custom domain name associated with the workgroup.
1666 1667 1668 1669 1670 1671 1672 1673 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 1666 class ListCustomDomainAssociationsRequest < Struct.new( :custom_domain_certificate_arn, :custom_domain_name, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
An optional parameter that specifies the maximum number of results
to return. You can use nextToken to display the next page of
results.
1666 1667 1668 1669 1670 1671 1672 1673 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 1666 class ListCustomDomainAssociationsRequest < Struct.new( :custom_domain_certificate_arn, :custom_domain_name, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
When nextToken is returned, there are more results available. The
value of nextToken is a unique pagination token for each page.
Make the call again using the returned token to retrieve the next
page.
1666 1667 1668 1669 1670 1671 1672 1673 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 1666 class ListCustomDomainAssociationsRequest < Struct.new( :custom_domain_certificate_arn, :custom_domain_name, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |