Class: Aws::RedshiftServerless::Types::ListManagedWorkgroupsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-redshiftserverless/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_resultsInteger

An optional parameter that specifies the maximum number of results to return. You can use nextToken to display the next page of results.

Returns:

  • (Integer)


1773
1774
1775
1776
1777
1778
1779
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 1773

class ListManagedWorkgroupsRequest < Struct.new(
  :max_results,
  :next_token,
  :source_arn)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

If your initial ListManagedWorkgroups operation returns a nextToken, you can include the returned nextToken in following ListManagedWorkgroups operations, which returns results in the next page.

Returns:

  • (String)


1773
1774
1775
1776
1777
1778
1779
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 1773

class ListManagedWorkgroupsRequest < Struct.new(
  :max_results,
  :next_token,
  :source_arn)
  SENSITIVE = []
  include Aws::Structure
end

#source_arnString

The Amazon Resource Name (ARN) for the managed workgroup in the Glue Data Catalog.

Returns:

  • (String)


1773
1774
1775
1776
1777
1778
1779
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 1773

class ListManagedWorkgroupsRequest < Struct.new(
  :max_results,
  :next_token,
  :source_arn)
  SENSITIVE = []
  include Aws::Structure
end