Class: Aws::RedshiftServerless::Types::ListRecoveryPointsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::RedshiftServerless::Types::ListRecoveryPointsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-redshiftserverless/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#end_time ⇒ Time
The time when creation of the recovery point finished.
-
#max_results ⇒ Integer
An optional parameter that specifies the maximum number of results to return.
-
#namespace_arn ⇒ String
The Amazon Resource Name (ARN) of the namespace from which to list recovery points.
-
#namespace_name ⇒ String
The name of the namespace to list recovery points for.
-
#next_token ⇒ String
If your initial
ListRecoveryPointsoperation returns anextToken, you can include the returnednextTokenin followingListRecoveryPointsoperations, which returns results in the next page. -
#start_time ⇒ Time
The time when the recovery point's creation was initiated.
Instance Attribute Details
#end_time ⇒ Time
The time when creation of the recovery point finished.
1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 1876 class ListRecoveryPointsRequest < Struct.new( :end_time, :max_results, :namespace_arn, :namespace_name, :next_token, :start_time) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
An optional parameter that specifies the maximum number of results
to return. You can use nextToken to display the next page of
results.
1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 1876 class ListRecoveryPointsRequest < Struct.new( :end_time, :max_results, :namespace_arn, :namespace_name, :next_token, :start_time) SENSITIVE = [] include Aws::Structure end |
#namespace_arn ⇒ String
The Amazon Resource Name (ARN) of the namespace from which to list recovery points.
1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 1876 class ListRecoveryPointsRequest < Struct.new( :end_time, :max_results, :namespace_arn, :namespace_name, :next_token, :start_time) SENSITIVE = [] include Aws::Structure end |
#namespace_name ⇒ String
The name of the namespace to list recovery points for.
1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 1876 class ListRecoveryPointsRequest < Struct.new( :end_time, :max_results, :namespace_arn, :namespace_name, :next_token, :start_time) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If your initial ListRecoveryPoints operation returns a
nextToken, you can include the returned nextToken in following
ListRecoveryPoints operations, which returns results in the next
page.
1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 1876 class ListRecoveryPointsRequest < Struct.new( :end_time, :max_results, :namespace_arn, :namespace_name, :next_token, :start_time) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ Time
The time when the recovery point's creation was initiated.
1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 1876 class ListRecoveryPointsRequest < Struct.new( :end_time, :max_results, :namespace_arn, :namespace_name, :next_token, :start_time) SENSITIVE = [] include Aws::Structure end |