Class: Aws::RedshiftServerless::Types::ListSnapshotCopyConfigurationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::RedshiftServerless::Types::ListSnapshotCopyConfigurationsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-redshiftserverless/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
An optional parameter that specifies the maximum number of results to return.
-
#namespace_name ⇒ String
The namespace from which to list all snapshot copy configurations.
-
#next_token ⇒ String
If
nextTokenis returned, there are more results available.
Instance Attribute Details
#max_results ⇒ Integer
An optional parameter that specifies the maximum number of results
to return. You can use nextToken to display the next page of
results.
2046 2047 2048 2049 2050 2051 2052 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 2046 class ListSnapshotCopyConfigurationsRequest < Struct.new( :max_results, :namespace_name, :next_token) SENSITIVE = [] include Aws::Structure end |
#namespace_name ⇒ String
The namespace from which to list all snapshot copy configurations.
2046 2047 2048 2049 2050 2051 2052 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 2046 class ListSnapshotCopyConfigurationsRequest < Struct.new( :max_results, :namespace_name, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If nextToken is returned, there are more results available. The
value of nextToken is a unique pagination token for each page.
Make the call again using the returned token to retrieve the next
page.
2046 2047 2048 2049 2050 2051 2052 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 2046 class ListSnapshotCopyConfigurationsRequest < Struct.new( :max_results, :namespace_name, :next_token) SENSITIVE = [] include Aws::Structure end |