Class: Aws::RedshiftServerless::Types::ListSnapshotCopyConfigurationsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-redshiftserverless/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

If nextToken is returned, there are more results available. The value of nextToken is a unique pagination token for each page. Make the call again using the returned token to retrieve the next page.

Returns:

  • (String)


2065
2066
2067
2068
2069
2070
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 2065

class ListSnapshotCopyConfigurationsResponse < Struct.new(
  :next_token,
  :snapshot_copy_configurations)
  SENSITIVE = []
  include Aws::Structure
end

#snapshot_copy_configurationsArray<Types::SnapshotCopyConfiguration>

All of the returned snapshot copy configurations.



2065
2066
2067
2068
2069
2070
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 2065

class ListSnapshotCopyConfigurationsResponse < Struct.new(
  :next_token,
  :snapshot_copy_configurations)
  SENSITIVE = []
  include Aws::Structure
end