Class: Aws::RedshiftServerless::Types::ListUsageLimitsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::RedshiftServerless::Types::ListUsageLimitsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-redshiftserverless/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
An optional parameter that specifies the maximum number of results to return.
-
#next_token ⇒ String
If your initial
ListUsageLimitsoperation returns anextToken, you can include the returnednextTokenin followingListUsageLimitsoperations, which returns results in the next page. -
#resource_arn ⇒ String
The Amazon Resource Name (ARN) associated with the resource whose usage limits you want to list.
-
#usage_type ⇒ String
The Amazon Redshift Serverless feature whose limits you want to see.
Instance Attribute Details
#max_results ⇒ Integer
An optional parameter that specifies the maximum number of results
to return. You can use nextToken to get the next page of results.
The default is 100.
2288 2289 2290 2291 2292 2293 2294 2295 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 2288 class ListUsageLimitsRequest < Struct.new( :max_results, :next_token, :resource_arn, :usage_type) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If your initial ListUsageLimits operation returns a nextToken,
you can include the returned nextToken in following
ListUsageLimits operations, which returns results in the next
page.
2288 2289 2290 2291 2292 2293 2294 2295 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 2288 class ListUsageLimitsRequest < Struct.new( :max_results, :next_token, :resource_arn, :usage_type) SENSITIVE = [] include Aws::Structure end |
#resource_arn ⇒ String
The Amazon Resource Name (ARN) associated with the resource whose usage limits you want to list.
2288 2289 2290 2291 2292 2293 2294 2295 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 2288 class ListUsageLimitsRequest < Struct.new( :max_results, :next_token, :resource_arn, :usage_type) SENSITIVE = [] include Aws::Structure end |
#usage_type ⇒ String
The Amazon Redshift Serverless feature whose limits you want to see.
2288 2289 2290 2291 2292 2293 2294 2295 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 2288 class ListUsageLimitsRequest < Struct.new( :max_results, :next_token, :resource_arn, :usage_type) SENSITIVE = [] include Aws::Structure end |