Class: Aws::RedshiftServerless::Types::ListWorkgroupsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::RedshiftServerless::Types::ListWorkgroupsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-redshiftserverless/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
An optional parameter that specifies the maximum number of results to return.
-
#next_token ⇒ String
If your initial ListWorkgroups operation returns a
nextToken, you can include the returnednextTokenin following ListNamespaces operations, which returns results in the next page. -
#owner_account ⇒ String
The owner Amazon Web Services account for the Amazon Redshift Serverless workgroup.
Instance Attribute Details
#max_results ⇒ Integer
An optional parameter that specifies the maximum number of results to return. You can use nextToken to display the next page of results.
2334 2335 2336 2337 2338 2339 2340 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 2334 class ListWorkgroupsRequest < Struct.new( :max_results, :next_token, :owner_account) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If your initial ListWorkgroups operation returns a nextToken, you can include the returned nextToken in following ListNamespaces operations, which returns results in the next page.
2334 2335 2336 2337 2338 2339 2340 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 2334 class ListWorkgroupsRequest < Struct.new( :max_results, :next_token, :owner_account) SENSITIVE = [] include Aws::Structure end |
#owner_account ⇒ String
The owner Amazon Web Services account for the Amazon Redshift Serverless workgroup.
2334 2335 2336 2337 2338 2339 2340 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 2334 class ListWorkgroupsRequest < Struct.new( :max_results, :next_token, :owner_account) SENSITIVE = [] include Aws::Structure end |