Class: Aws::RedshiftServerless::Types::Namespace

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-redshiftserverless/types.rb

Overview

A collection of database objects and users.

Constant Summary collapse

SENSITIVE =
[:admin_username]

Instance Attribute Summary collapse

Instance Attribute Details

#admin_password_secret_arnString

The Amazon Resource Name (ARN) for the namespace's admin user credentials secret.

Returns:

  • (String)


2486
2487
2488
2489
2490
2491
2492
2493
2494
2495
2496
2497
2498
2499
2500
2501
2502
2503
2504
2505
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 2486

class Namespace < Struct.new(
  :admin_password_secret_arn,
  :admin_password_secret_kms_key_id,
  :admin_username,
  :catalog_arn,
  :creation_date,
  :db_name,
  :default_iam_role_arn,
  :iam_roles,
  :kms_key_id,
  :lakehouse_registration_status,
  :log_exports,
  :namespace_arn,
  :namespace_id,
  :namespace_name,
  :s3_table_publish_status,
  :status)
  SENSITIVE = [:admin_username]
  include Aws::Structure
end

#admin_password_secret_kms_key_idString

The ID of the Key Management Service (KMS) key used to encrypt and store the namespace's admin credentials secret.

Returns:

  • (String)


2486
2487
2488
2489
2490
2491
2492
2493
2494
2495
2496
2497
2498
2499
2500
2501
2502
2503
2504
2505
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 2486

class Namespace < Struct.new(
  :admin_password_secret_arn,
  :admin_password_secret_kms_key_id,
  :admin_username,
  :catalog_arn,
  :creation_date,
  :db_name,
  :default_iam_role_arn,
  :iam_roles,
  :kms_key_id,
  :lakehouse_registration_status,
  :log_exports,
  :namespace_arn,
  :namespace_id,
  :namespace_name,
  :s3_table_publish_status,
  :status)
  SENSITIVE = [:admin_username]
  include Aws::Structure
end

#admin_usernameString

The username of the administrator for the first database created in the namespace.

Returns:

  • (String)


2486
2487
2488
2489
2490
2491
2492
2493
2494
2495
2496
2497
2498
2499
2500
2501
2502
2503
2504
2505
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 2486

class Namespace < Struct.new(
  :admin_password_secret_arn,
  :admin_password_secret_kms_key_id,
  :admin_username,
  :catalog_arn,
  :creation_date,
  :db_name,
  :default_iam_role_arn,
  :iam_roles,
  :kms_key_id,
  :lakehouse_registration_status,
  :log_exports,
  :namespace_arn,
  :namespace_id,
  :namespace_name,
  :s3_table_publish_status,
  :status)
  SENSITIVE = [:admin_username]
  include Aws::Structure
end

#catalog_arnString

The Amazon Resource Name (ARN) of the Glue Data Catalog associated with the namespace enabled with Amazon Redshift federated permissions.

Returns:

  • (String)


2486
2487
2488
2489
2490
2491
2492
2493
2494
2495
2496
2497
2498
2499
2500
2501
2502
2503
2504
2505
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 2486

class Namespace < Struct.new(
  :admin_password_secret_arn,
  :admin_password_secret_kms_key_id,
  :admin_username,
  :catalog_arn,
  :creation_date,
  :db_name,
  :default_iam_role_arn,
  :iam_roles,
  :kms_key_id,
  :lakehouse_registration_status,
  :log_exports,
  :namespace_arn,
  :namespace_id,
  :namespace_name,
  :s3_table_publish_status,
  :status)
  SENSITIVE = [:admin_username]
  include Aws::Structure
end

#creation_dateTime

The date of when the namespace was created.

Returns:

  • (Time)


2486
2487
2488
2489
2490
2491
2492
2493
2494
2495
2496
2497
2498
2499
2500
2501
2502
2503
2504
2505
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 2486

class Namespace < Struct.new(
  :admin_password_secret_arn,
  :admin_password_secret_kms_key_id,
  :admin_username,
  :catalog_arn,
  :creation_date,
  :db_name,
  :default_iam_role_arn,
  :iam_roles,
  :kms_key_id,
  :lakehouse_registration_status,
  :log_exports,
  :namespace_arn,
  :namespace_id,
  :namespace_name,
  :s3_table_publish_status,
  :status)
  SENSITIVE = [:admin_username]
  include Aws::Structure
end

#db_nameString

The name of the first database created in the namespace.

Returns:

  • (String)


2486
2487
2488
2489
2490
2491
2492
2493
2494
2495
2496
2497
2498
2499
2500
2501
2502
2503
2504
2505
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 2486

class Namespace < Struct.new(
  :admin_password_secret_arn,
  :admin_password_secret_kms_key_id,
  :admin_username,
  :catalog_arn,
  :creation_date,
  :db_name,
  :default_iam_role_arn,
  :iam_roles,
  :kms_key_id,
  :lakehouse_registration_status,
  :log_exports,
  :namespace_arn,
  :namespace_id,
  :namespace_name,
  :s3_table_publish_status,
  :status)
  SENSITIVE = [:admin_username]
  include Aws::Structure
end

#default_iam_role_arnString

The Amazon Resource Name (ARN) of the IAM role to set as a default in the namespace.

Returns:

  • (String)


2486
2487
2488
2489
2490
2491
2492
2493
2494
2495
2496
2497
2498
2499
2500
2501
2502
2503
2504
2505
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 2486

class Namespace < Struct.new(
  :admin_password_secret_arn,
  :admin_password_secret_kms_key_id,
  :admin_username,
  :catalog_arn,
  :creation_date,
  :db_name,
  :default_iam_role_arn,
  :iam_roles,
  :kms_key_id,
  :lakehouse_registration_status,
  :log_exports,
  :namespace_arn,
  :namespace_id,
  :namespace_name,
  :s3_table_publish_status,
  :status)
  SENSITIVE = [:admin_username]
  include Aws::Structure
end

#iam_rolesArray<String>

A list of IAM roles to associate with the namespace.

Returns:

  • (Array<String>)


2486
2487
2488
2489
2490
2491
2492
2493
2494
2495
2496
2497
2498
2499
2500
2501
2502
2503
2504
2505
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 2486

class Namespace < Struct.new(
  :admin_password_secret_arn,
  :admin_password_secret_kms_key_id,
  :admin_username,
  :catalog_arn,
  :creation_date,
  :db_name,
  :default_iam_role_arn,
  :iam_roles,
  :kms_key_id,
  :lakehouse_registration_status,
  :log_exports,
  :namespace_arn,
  :namespace_id,
  :namespace_name,
  :s3_table_publish_status,
  :status)
  SENSITIVE = [:admin_username]
  include Aws::Structure
end

#kms_key_idString

The ID of the Amazon Web Services Key Management Service key used to encrypt your data.

Returns:

  • (String)


2486
2487
2488
2489
2490
2491
2492
2493
2494
2495
2496
2497
2498
2499
2500
2501
2502
2503
2504
2505
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 2486

class Namespace < Struct.new(
  :admin_password_secret_arn,
  :admin_password_secret_kms_key_id,
  :admin_username,
  :catalog_arn,
  :creation_date,
  :db_name,
  :default_iam_role_arn,
  :iam_roles,
  :kms_key_id,
  :lakehouse_registration_status,
  :log_exports,
  :namespace_arn,
  :namespace_id,
  :namespace_name,
  :s3_table_publish_status,
  :status)
  SENSITIVE = [:admin_username]
  include Aws::Structure
end

#lakehouse_registration_statusString

The status of the lakehouse registration for the namespace. Indicates whether the namespace is successfully registered with Amazon Redshift federated permissions.

Returns:

  • (String)


2486
2487
2488
2489
2490
2491
2492
2493
2494
2495
2496
2497
2498
2499
2500
2501
2502
2503
2504
2505
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 2486

class Namespace < Struct.new(
  :admin_password_secret_arn,
  :admin_password_secret_kms_key_id,
  :admin_username,
  :catalog_arn,
  :creation_date,
  :db_name,
  :default_iam_role_arn,
  :iam_roles,
  :kms_key_id,
  :lakehouse_registration_status,
  :log_exports,
  :namespace_arn,
  :namespace_id,
  :namespace_name,
  :s3_table_publish_status,
  :status)
  SENSITIVE = [:admin_username]
  include Aws::Structure
end

#log_exportsArray<String>

The types of logs the namespace can export. Available export types are User log, Connection log, and User activity log.

Returns:

  • (Array<String>)


2486
2487
2488
2489
2490
2491
2492
2493
2494
2495
2496
2497
2498
2499
2500
2501
2502
2503
2504
2505
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 2486

class Namespace < Struct.new(
  :admin_password_secret_arn,
  :admin_password_secret_kms_key_id,
  :admin_username,
  :catalog_arn,
  :creation_date,
  :db_name,
  :default_iam_role_arn,
  :iam_roles,
  :kms_key_id,
  :lakehouse_registration_status,
  :log_exports,
  :namespace_arn,
  :namespace_id,
  :namespace_name,
  :s3_table_publish_status,
  :status)
  SENSITIVE = [:admin_username]
  include Aws::Structure
end

#namespace_arnString

The Amazon Resource Name (ARN) associated with a namespace.

Returns:

  • (String)


2486
2487
2488
2489
2490
2491
2492
2493
2494
2495
2496
2497
2498
2499
2500
2501
2502
2503
2504
2505
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 2486

class Namespace < Struct.new(
  :admin_password_secret_arn,
  :admin_password_secret_kms_key_id,
  :admin_username,
  :catalog_arn,
  :creation_date,
  :db_name,
  :default_iam_role_arn,
  :iam_roles,
  :kms_key_id,
  :lakehouse_registration_status,
  :log_exports,
  :namespace_arn,
  :namespace_id,
  :namespace_name,
  :s3_table_publish_status,
  :status)
  SENSITIVE = [:admin_username]
  include Aws::Structure
end

#namespace_idString

The unique identifier of a namespace.

Returns:

  • (String)


2486
2487
2488
2489
2490
2491
2492
2493
2494
2495
2496
2497
2498
2499
2500
2501
2502
2503
2504
2505
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 2486

class Namespace < Struct.new(
  :admin_password_secret_arn,
  :admin_password_secret_kms_key_id,
  :admin_username,
  :catalog_arn,
  :creation_date,
  :db_name,
  :default_iam_role_arn,
  :iam_roles,
  :kms_key_id,
  :lakehouse_registration_status,
  :log_exports,
  :namespace_arn,
  :namespace_id,
  :namespace_name,
  :s3_table_publish_status,
  :status)
  SENSITIVE = [:admin_username]
  include Aws::Structure
end

#namespace_nameString

The name of the namespace. Must be between 3-64 alphanumeric characters in lowercase, and it cannot be a reserved word. A list of reserved words can be found in Reserved Words in the Amazon Redshift Database Developer Guide.

Returns:

  • (String)


2486
2487
2488
2489
2490
2491
2492
2493
2494
2495
2496
2497
2498
2499
2500
2501
2502
2503
2504
2505
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 2486

class Namespace < Struct.new(
  :admin_password_secret_arn,
  :admin_password_secret_kms_key_id,
  :admin_username,
  :catalog_arn,
  :creation_date,
  :db_name,
  :default_iam_role_arn,
  :iam_roles,
  :kms_key_id,
  :lakehouse_registration_status,
  :log_exports,
  :namespace_arn,
  :namespace_id,
  :namespace_name,
  :s3_table_publish_status,
  :status)
  SENSITIVE = [:admin_username]
  include Aws::Structure
end

#s3_table_publish_statusTypes::S3TablePublishStatus

The current Amazon S3 Tables log-publishing status for the namespace. Not returned when S3 Tables publishing has never been configured for the namespace.



2486
2487
2488
2489
2490
2491
2492
2493
2494
2495
2496
2497
2498
2499
2500
2501
2502
2503
2504
2505
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 2486

class Namespace < Struct.new(
  :admin_password_secret_arn,
  :admin_password_secret_kms_key_id,
  :admin_username,
  :catalog_arn,
  :creation_date,
  :db_name,
  :default_iam_role_arn,
  :iam_roles,
  :kms_key_id,
  :lakehouse_registration_status,
  :log_exports,
  :namespace_arn,
  :namespace_id,
  :namespace_name,
  :s3_table_publish_status,
  :status)
  SENSITIVE = [:admin_username]
  include Aws::Structure
end

#statusString

The status of the namespace.

Returns:

  • (String)


2486
2487
2488
2489
2490
2491
2492
2493
2494
2495
2496
2497
2498
2499
2500
2501
2502
2503
2504
2505
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 2486

class Namespace < Struct.new(
  :admin_password_secret_arn,
  :admin_password_secret_kms_key_id,
  :admin_username,
  :catalog_arn,
  :creation_date,
  :db_name,
  :default_iam_role_arn,
  :iam_roles,
  :kms_key_id,
  :lakehouse_registration_status,
  :log_exports,
  :namespace_arn,
  :namespace_id,
  :namespace_name,
  :s3_table_publish_status,
  :status)
  SENSITIVE = [:admin_username]
  include Aws::Structure
end