Class: Aws::RedshiftServerless::Types::Reservation
- Inherits:
-
Struct
- Object
- Struct
- Aws::RedshiftServerless::Types::Reservation
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-redshiftserverless/types.rb
Overview
Represents an Amazon Redshift Serverless reservation, which gives you the option to commit to a specified number of Redshift Processing Units (RPUs) for a year at a discount from Serverless on-demand (OD) rates.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#capacity ⇒ Integer
The number of Redshift Processing Units (RPUs) to reserve.
-
#end_date ⇒ Time
The end date for the serverless reservation.
-
#offering ⇒ Types::ReservationOffering
The type of offering for the reservation.
-
#reservation_arn ⇒ String
The Amazon Resource Name (ARN) that uniquely identifies the serverless reservation.
-
#reservation_id ⇒ String
The identifier that uniquely identifies the serverless reservation.
-
#start_date ⇒ Time
The start date for the serverless reservation.
-
#status ⇒ String
The status of the reservation.
Instance Attribute Details
#capacity ⇒ Integer
The number of Redshift Processing Units (RPUs) to reserve.
2691 2692 2693 2694 2695 2696 2697 2698 2699 2700 2701 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 2691 class Reservation < Struct.new( :capacity, :end_date, :offering, :reservation_arn, :reservation_id, :start_date, :status) SENSITIVE = [] include Aws::Structure end |
#end_date ⇒ Time
The end date for the serverless reservation. This date is one year after the start date that you specify.
2691 2692 2693 2694 2695 2696 2697 2698 2699 2700 2701 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 2691 class Reservation < Struct.new( :capacity, :end_date, :offering, :reservation_arn, :reservation_id, :start_date, :status) SENSITIVE = [] include Aws::Structure end |
#offering ⇒ Types::ReservationOffering
The type of offering for the reservation. The offering class determines the payment schedule for the reservation.
2691 2692 2693 2694 2695 2696 2697 2698 2699 2700 2701 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 2691 class Reservation < Struct.new( :capacity, :end_date, :offering, :reservation_arn, :reservation_id, :start_date, :status) SENSITIVE = [] include Aws::Structure end |
#reservation_arn ⇒ String
The Amazon Resource Name (ARN) that uniquely identifies the serverless reservation.
2691 2692 2693 2694 2695 2696 2697 2698 2699 2700 2701 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 2691 class Reservation < Struct.new( :capacity, :end_date, :offering, :reservation_arn, :reservation_id, :start_date, :status) SENSITIVE = [] include Aws::Structure end |
#reservation_id ⇒ String
The identifier that uniquely identifies the serverless reservation.
2691 2692 2693 2694 2695 2696 2697 2698 2699 2700 2701 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 2691 class Reservation < Struct.new( :capacity, :end_date, :offering, :reservation_arn, :reservation_id, :start_date, :status) SENSITIVE = [] include Aws::Structure end |
#start_date ⇒ Time
The start date for the serverless reservation. This is the date you created the reservation.
2691 2692 2693 2694 2695 2696 2697 2698 2699 2700 2701 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 2691 class Reservation < Struct.new( :capacity, :end_date, :offering, :reservation_arn, :reservation_id, :start_date, :status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the reservation. Possible values include the following:
-
payment-pending -
active -
payment-failed -
retired
2691 2692 2693 2694 2695 2696 2697 2698 2699 2700 2701 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 2691 class Reservation < Struct.new( :capacity, :end_date, :offering, :reservation_arn, :reservation_id, :start_date, :status) SENSITIVE = [] include Aws::Structure end |