Class: Aws::RedshiftServerless::Types::RestoreFromRecoveryPointRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-redshiftserverless/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#maintain_integrationBoolean

If true, maintain existing data sharing, zero-ETL and S3 event integrations when restoring. Otherwise, integrations will not be maintained after the restore operation. Integrations are only maintained when restored to the same serverless namespace.

Default: true

Returns:

  • (Boolean)


2798
2799
2800
2801
2802
2803
2804
2805
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 2798

class RestoreFromRecoveryPointRequest < Struct.new(
  :maintain_integration,
  :namespace_name,
  :recovery_point_id,
  :workgroup_name)
  SENSITIVE = []
  include Aws::Structure
end

#namespace_nameString

The name of the namespace to restore data into.

Returns:

  • (String)


2798
2799
2800
2801
2802
2803
2804
2805
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 2798

class RestoreFromRecoveryPointRequest < Struct.new(
  :maintain_integration,
  :namespace_name,
  :recovery_point_id,
  :workgroup_name)
  SENSITIVE = []
  include Aws::Structure
end

#recovery_point_idString

The unique identifier of the recovery point to restore from.

Returns:

  • (String)


2798
2799
2800
2801
2802
2803
2804
2805
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 2798

class RestoreFromRecoveryPointRequest < Struct.new(
  :maintain_integration,
  :namespace_name,
  :recovery_point_id,
  :workgroup_name)
  SENSITIVE = []
  include Aws::Structure
end

#workgroup_nameString

The name of the workgroup used to restore data.

Returns:

  • (String)


2798
2799
2800
2801
2802
2803
2804
2805
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 2798

class RestoreFromRecoveryPointRequest < Struct.new(
  :maintain_integration,
  :namespace_name,
  :recovery_point_id,
  :workgroup_name)
  SENSITIVE = []
  include Aws::Structure
end