Class: Aws::RedshiftServerless::Types::RestoreFromSnapshotRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::RedshiftServerless::Types::RestoreFromSnapshotRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-redshiftserverless/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#admin_password_secret_kms_key_id ⇒ String
The ID of the Key Management Service (KMS) key used to encrypt and store the namespace’s admin credentials secret.
-
#manage_admin_password ⇒ Boolean
If
true, Amazon Redshift uses Secrets Manager to manage the restored snapshot’s admin credentials. -
#namespace_name ⇒ String
The name of the namespace to restore the snapshot to.
-
#owner_account ⇒ String
The Amazon Web Services account that owns the snapshot.
-
#snapshot_arn ⇒ String
The Amazon Resource Name (ARN) of the snapshot to restore from.
-
#snapshot_name ⇒ String
The name of the snapshot to restore from.
-
#workgroup_name ⇒ String
The name of the workgroup used to restore the snapshot.
Instance Attribute Details
#admin_password_secret_kms_key_id ⇒ String
The ID of the Key Management Service (KMS) key used to encrypt and store the namespace’s admin credentials secret.
2853 2854 2855 2856 2857 2858 2859 2860 2861 2862 2863 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 2853 class RestoreFromSnapshotRequest < Struct.new( :admin_password_secret_kms_key_id, :manage_admin_password, :namespace_name, :owner_account, :snapshot_arn, :snapshot_name, :workgroup_name) SENSITIVE = [] include Aws::Structure end |
#manage_admin_password ⇒ Boolean
If true, Amazon Redshift uses Secrets Manager to manage the restored snapshot’s admin credentials. If MmanageAdminPassword is false or not set, Amazon Redshift uses the admin credentials that the namespace or cluster had at the time the snapshot was taken.
2853 2854 2855 2856 2857 2858 2859 2860 2861 2862 2863 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 2853 class RestoreFromSnapshotRequest < Struct.new( :admin_password_secret_kms_key_id, :manage_admin_password, :namespace_name, :owner_account, :snapshot_arn, :snapshot_name, :workgroup_name) SENSITIVE = [] include Aws::Structure end |
#namespace_name ⇒ String
The name of the namespace to restore the snapshot to.
2853 2854 2855 2856 2857 2858 2859 2860 2861 2862 2863 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 2853 class RestoreFromSnapshotRequest < Struct.new( :admin_password_secret_kms_key_id, :manage_admin_password, :namespace_name, :owner_account, :snapshot_arn, :snapshot_name, :workgroup_name) SENSITIVE = [] include Aws::Structure end |
#owner_account ⇒ String
The Amazon Web Services account that owns the snapshot.
2853 2854 2855 2856 2857 2858 2859 2860 2861 2862 2863 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 2853 class RestoreFromSnapshotRequest < Struct.new( :admin_password_secret_kms_key_id, :manage_admin_password, :namespace_name, :owner_account, :snapshot_arn, :snapshot_name, :workgroup_name) SENSITIVE = [] include Aws::Structure end |
#snapshot_arn ⇒ String
The Amazon Resource Name (ARN) of the snapshot to restore from. Required if restoring from a provisioned cluster to Amazon Redshift Serverless. Must not be specified at the same time as snapshotName.
The format of the ARN is arn:aws:redshift:<region>:<account_id>:snapshot:<cluster_identifier>/<snapshot_identifier>.
2853 2854 2855 2856 2857 2858 2859 2860 2861 2862 2863 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 2853 class RestoreFromSnapshotRequest < Struct.new( :admin_password_secret_kms_key_id, :manage_admin_password, :namespace_name, :owner_account, :snapshot_arn, :snapshot_name, :workgroup_name) SENSITIVE = [] include Aws::Structure end |
#snapshot_name ⇒ String
The name of the snapshot to restore from. Must not be specified at the same time as snapshotArn.
2853 2854 2855 2856 2857 2858 2859 2860 2861 2862 2863 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 2853 class RestoreFromSnapshotRequest < Struct.new( :admin_password_secret_kms_key_id, :manage_admin_password, :namespace_name, :owner_account, :snapshot_arn, :snapshot_name, :workgroup_name) SENSITIVE = [] include Aws::Structure end |
#workgroup_name ⇒ String
The name of the workgroup used to restore the snapshot.
2853 2854 2855 2856 2857 2858 2859 2860 2861 2862 2863 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 2853 class RestoreFromSnapshotRequest < Struct.new( :admin_password_secret_kms_key_id, :manage_admin_password, :namespace_name, :owner_account, :snapshot_arn, :snapshot_name, :workgroup_name) SENSITIVE = [] include Aws::Structure end |