Class: Aws::RedshiftServerless::Types::S3TablePublishStatus

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-redshiftserverless/types.rb

Overview

Describes the state of Amazon S3 Tables system-table log publishing for a namespace.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#enabled_allBoolean

true when the namespace is enrolled in every current and future system table rather than an explicit list of tables.

Returns:

  • (Boolean)


3093
3094
3095
3096
3097
3098
3099
3100
3101
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3093

class S3TablePublishStatus < Struct.new(
  :enabled_all,
  :last_ingestion_times,
  :s3_table_granularity,
  :s3_table_namespace,
  :s3_tables)
  SENSITIVE = []
  include Aws::Structure
end

#last_ingestion_timesHash<String,String>

A map of system table name to the time that table last received data, as an ISO-8601 timestamp. A table that has not yet been ingested is absent from the map. Use it to judge data freshness.

Returns:

  • (Hash<String,String>)


3093
3094
3095
3096
3097
3098
3099
3100
3101
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3093

class S3TablePublishStatus < Struct.new(
  :enabled_all,
  :last_ingestion_times,
  :s3_table_granularity,
  :s3_table_namespace,
  :s3_tables)
  SENSITIVE = []
  include Aws::Structure
end

#s3_table_granularityString

The scope currently in effect. Values are namespace or account.

Returns:

  • (String)


3093
3094
3095
3096
3097
3098
3099
3100
3101
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3093

class S3TablePublishStatus < Struct.new(
  :enabled_all,
  :last_ingestion_times,
  :s3_table_granularity,
  :s3_table_namespace,
  :s3_tables)
  SENSITIVE = []
  include Aws::Structure
end

#s3_table_namespaceString

The identifier of the namespace in the S3 table bucket that holds the published tables.

Returns:

  • (String)


3093
3094
3095
3096
3097
3098
3099
3100
3101
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3093

class S3TablePublishStatus < Struct.new(
  :enabled_all,
  :last_ingestion_times,
  :s3_table_granularity,
  :s3_table_namespace,
  :s3_tables)
  SENSITIVE = []
  include Aws::Structure
end

#s3_tablesArray<String>

The system tables currently being published.

Returns:

  • (Array<String>)


3093
3094
3095
3096
3097
3098
3099
3100
3101
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3093

class S3TablePublishStatus < Struct.new(
  :enabled_all,
  :last_ingestion_times,
  :s3_table_granularity,
  :s3_table_namespace,
  :s3_tables)
  SENSITIVE = []
  include Aws::Structure
end