Class: Aws::RedshiftServerless::Types::ScheduledActionResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::RedshiftServerless::Types::ScheduledActionResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-redshiftserverless/types.rb
Overview
The returned scheduled action object.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#end_time ⇒ Time
The end time of.
-
#namespace_name ⇒ String
The end time in UTC when the schedule is no longer active.
-
#next_invocations ⇒ Array<Time>
An array of timestamps of when the next scheduled actions will trigger.
-
#role_arn ⇒ String
The ARN of the IAM role to assume to run the scheduled action.
-
#schedule ⇒ Types::Schedule
The schedule for a one-time (at timestamp format) or recurring (cron format) scheduled action.
-
#scheduled_action_description ⇒ String
The description of the scheduled action.
-
#scheduled_action_name ⇒ String
The name of the scheduled action.
-
#scheduled_action_uuid ⇒ String
The uuid of the scheduled action.
-
#start_time ⇒ Time
The start time in UTC when the schedule is active.
-
#state ⇒ String
The state of the scheduled action.
-
#target_action ⇒ Types::TargetAction
A JSON format string of the Amazon Redshift Serverless API operation with input parameters.
Instance Attribute Details
#end_time ⇒ Time
The end time of
3201 3202 3203 3204 3205 3206 3207 3208 3209 3210 3211 3212 3213 3214 3215 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3201 class ScheduledActionResponse < Struct.new( :end_time, :namespace_name, :next_invocations, :role_arn, :schedule, :scheduled_action_description, :scheduled_action_name, :scheduled_action_uuid, :start_time, :state, :target_action) SENSITIVE = [] include Aws::Structure end |
#namespace_name ⇒ String
The end time in UTC when the schedule is no longer active. After this time, the scheduled action does not trigger.
3201 3202 3203 3204 3205 3206 3207 3208 3209 3210 3211 3212 3213 3214 3215 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3201 class ScheduledActionResponse < Struct.new( :end_time, :namespace_name, :next_invocations, :role_arn, :schedule, :scheduled_action_description, :scheduled_action_name, :scheduled_action_uuid, :start_time, :state, :target_action) SENSITIVE = [] include Aws::Structure end |
#next_invocations ⇒ Array<Time>
An array of timestamps of when the next scheduled actions will trigger.
3201 3202 3203 3204 3205 3206 3207 3208 3209 3210 3211 3212 3213 3214 3215 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3201 class ScheduledActionResponse < Struct.new( :end_time, :namespace_name, :next_invocations, :role_arn, :schedule, :scheduled_action_description, :scheduled_action_name, :scheduled_action_uuid, :start_time, :state, :target_action) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The ARN of the IAM role to assume to run the scheduled action. This IAM role must have permission to run the Amazon Redshift Serverless API operation in the scheduled action. This IAM role must allow the Amazon Redshift scheduler to schedule creating snapshots. (Principal scheduler.redshift.amazonaws.com) to assume permissions on your behalf. For more information about the IAM role to use with the Amazon Redshift scheduler, see Using Identity-Based Policies for Amazon Redshift in the Amazon Redshift Management Guide
3201 3202 3203 3204 3205 3206 3207 3208 3209 3210 3211 3212 3213 3214 3215 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3201 class ScheduledActionResponse < Struct.new( :end_time, :namespace_name, :next_invocations, :role_arn, :schedule, :scheduled_action_description, :scheduled_action_name, :scheduled_action_uuid, :start_time, :state, :target_action) SENSITIVE = [] include Aws::Structure end |
#schedule ⇒ Types::Schedule
The schedule for a one-time (at timestamp format) or recurring (cron format) scheduled action. Schedule invocations must be separated by at least one hour. Times are in UTC.
-
Format of at timestamp is
yyyy-mm-ddThh:mm:ss. For example,2016-03-04T17:27:00. -
Format of cron expression is
(Minutes Hours Day-of-month Month Day-of-week Year). For example,"(0 10 ? * MON *)". For more information, see Cron Expressions in the Amazon CloudWatch Events User Guide.
3201 3202 3203 3204 3205 3206 3207 3208 3209 3210 3211 3212 3213 3214 3215 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3201 class ScheduledActionResponse < Struct.new( :end_time, :namespace_name, :next_invocations, :role_arn, :schedule, :scheduled_action_description, :scheduled_action_name, :scheduled_action_uuid, :start_time, :state, :target_action) SENSITIVE = [] include Aws::Structure end |
#scheduled_action_description ⇒ String
The description of the scheduled action.
3201 3202 3203 3204 3205 3206 3207 3208 3209 3210 3211 3212 3213 3214 3215 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3201 class ScheduledActionResponse < Struct.new( :end_time, :namespace_name, :next_invocations, :role_arn, :schedule, :scheduled_action_description, :scheduled_action_name, :scheduled_action_uuid, :start_time, :state, :target_action) SENSITIVE = [] include Aws::Structure end |
#scheduled_action_name ⇒ String
The name of the scheduled action.
3201 3202 3203 3204 3205 3206 3207 3208 3209 3210 3211 3212 3213 3214 3215 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3201 class ScheduledActionResponse < Struct.new( :end_time, :namespace_name, :next_invocations, :role_arn, :schedule, :scheduled_action_description, :scheduled_action_name, :scheduled_action_uuid, :start_time, :state, :target_action) SENSITIVE = [] include Aws::Structure end |
#scheduled_action_uuid ⇒ String
The uuid of the scheduled action.
3201 3202 3203 3204 3205 3206 3207 3208 3209 3210 3211 3212 3213 3214 3215 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3201 class ScheduledActionResponse < Struct.new( :end_time, :namespace_name, :next_invocations, :role_arn, :schedule, :scheduled_action_description, :scheduled_action_name, :scheduled_action_uuid, :start_time, :state, :target_action) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ Time
The start time in UTC when the schedule is active. Before this time, the scheduled action does not trigger.
3201 3202 3203 3204 3205 3206 3207 3208 3209 3210 3211 3212 3213 3214 3215 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3201 class ScheduledActionResponse < Struct.new( :end_time, :namespace_name, :next_invocations, :role_arn, :schedule, :scheduled_action_description, :scheduled_action_name, :scheduled_action_uuid, :start_time, :state, :target_action) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The state of the scheduled action.
3201 3202 3203 3204 3205 3206 3207 3208 3209 3210 3211 3212 3213 3214 3215 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3201 class ScheduledActionResponse < Struct.new( :end_time, :namespace_name, :next_invocations, :role_arn, :schedule, :scheduled_action_description, :scheduled_action_name, :scheduled_action_uuid, :start_time, :state, :target_action) SENSITIVE = [] include Aws::Structure end |
#target_action ⇒ Types::TargetAction
A JSON format string of the Amazon Redshift Serverless API operation with input parameters. The following is an example of a target action.
"{"CreateSnapshot": {"NamespaceName": "sampleNamespace","SnapshotName": "sampleSnapshot", "retentionPeriod": "1"}}"
3201 3202 3203 3204 3205 3206 3207 3208 3209 3210 3211 3212 3213 3214 3215 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3201 class ScheduledActionResponse < Struct.new( :end_time, :namespace_name, :next_invocations, :role_arn, :schedule, :scheduled_action_description, :scheduled_action_name, :scheduled_action_uuid, :start_time, :state, :target_action) SENSITIVE = [] include Aws::Structure end |