Class: Aws::RedshiftServerless::Types::ServerlessTrack

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-redshiftserverless/types.rb

Overview

Defines a track that determines which Amazon Redshift version to apply after a new version is released. If the value for ServerlessTrack is current, the workgroup is updated to the most recently certified release. If the value is trailing, the workgroup is updated to the previously certified release.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#track_nameString

The name of the track. Valid values are current and trailing.

Returns:

  • (String)


3237
3238
3239
3240
3241
3242
3243
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3237

class ServerlessTrack < Struct.new(
  :track_name,
  :update_targets,
  :workgroup_version)
  SENSITIVE = []
  include Aws::Structure
end

#update_targetsArray<Types::UpdateTarget>

An array of UpdateTarget objects to update with the track.

Returns:



3237
3238
3239
3240
3241
3242
3243
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3237

class ServerlessTrack < Struct.new(
  :track_name,
  :update_targets,
  :workgroup_version)
  SENSITIVE = []
  include Aws::Structure
end

#workgroup_versionString

The workgroup version number for the workgroup release.

Returns:

  • (String)


3237
3238
3239
3240
3241
3242
3243
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3237

class ServerlessTrack < Struct.new(
  :track_name,
  :update_targets,
  :workgroup_version)
  SENSITIVE = []
  include Aws::Structure
end