Class: Aws::RedshiftServerless::Types::Snapshot
- Inherits:
-
Struct
- Object
- Struct
- Aws::RedshiftServerless::Types::Snapshot
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-redshiftserverless/types.rb
Overview
A snapshot object that contains databases.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#accounts_with_provisioned_restore_access ⇒ Array<String>
All of the Amazon Web Services accounts that have access to restore a snapshot to a provisioned cluster.
-
#accounts_with_restore_access ⇒ Array<String>
All of the Amazon Web Services accounts that have access to restore a snapshot to a namespace.
-
#actual_incremental_backup_size_in_mega_bytes ⇒ Float
The size of the incremental backup in megabytes.
-
#admin_password_secret_arn ⇒ String
The Amazon Resource Name (ARN) for the namespace's admin user credentials secret.
-
#admin_password_secret_kms_key_id ⇒ String
The ID of the Key Management Service (KMS) key used to encrypt and store the namespace's admin credentials secret.
-
#admin_username ⇒ String
The username of the database within a snapshot.
-
#backup_progress_in_mega_bytes ⇒ Float
The size in megabytes of the data that has been backed up to a snapshot.
-
#current_backup_rate_in_mega_bytes_per_second ⇒ Float
The rate at which data is backed up into a snapshot in megabytes per second.
-
#elapsed_time_in_seconds ⇒ Integer
The amount of time it took to back up data into a snapshot.
-
#estimated_seconds_to_completion ⇒ Integer
The estimated amount of seconds until the snapshot completes backup.
-
#kms_key_id ⇒ String
The unique identifier of the KMS key used to encrypt the snapshot.
-
#namespace_arn ⇒ String
The Amazon Resource Name (ARN) of the namespace the snapshot was created from.
-
#namespace_name ⇒ String
The name of the namepsace.
-
#owner_account ⇒ String
The owner Amazon Web Services; account of the snapshot.
-
#snapshot_arn ⇒ String
The Amazon Resource Name (ARN) of the snapshot.
-
#snapshot_create_time ⇒ Time
The timestamp of when the snapshot was created.
-
#snapshot_name ⇒ String
The name of the snapshot.
-
#snapshot_remaining_days ⇒ Integer
The amount of days until the snapshot is deleted.
-
#snapshot_retention_period ⇒ Integer
The period of time, in days, of how long the snapshot is retained.
-
#snapshot_retention_start_time ⇒ Time
The timestamp of when data within the snapshot started getting retained.
-
#status ⇒ String
The status of the snapshot.
-
#total_backup_size_in_mega_bytes ⇒ Float
The total size, in megabytes, of how big the snapshot is.
Instance Attribute Details
#accounts_with_provisioned_restore_access ⇒ Array<String>
All of the Amazon Web Services accounts that have access to restore a snapshot to a provisioned cluster.
3404 3405 3406 3407 3408 3409 3410 3411 3412 3413 3414 3415 3416 3417 3418 3419 3420 3421 3422 3423 3424 3425 3426 3427 3428 3429 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3404 class Snapshot < Struct.new( :accounts_with_provisioned_restore_access, :accounts_with_restore_access, :actual_incremental_backup_size_in_mega_bytes, :admin_password_secret_arn, :admin_password_secret_kms_key_id, :admin_username, :backup_progress_in_mega_bytes, :current_backup_rate_in_mega_bytes_per_second, :elapsed_time_in_seconds, :estimated_seconds_to_completion, :kms_key_id, :namespace_arn, :namespace_name, :owner_account, :snapshot_arn, :snapshot_create_time, :snapshot_name, :snapshot_remaining_days, :snapshot_retention_period, :snapshot_retention_start_time, :status, :total_backup_size_in_mega_bytes) SENSITIVE = [] include Aws::Structure end |
#accounts_with_restore_access ⇒ Array<String>
All of the Amazon Web Services accounts that have access to restore a snapshot to a namespace.
3404 3405 3406 3407 3408 3409 3410 3411 3412 3413 3414 3415 3416 3417 3418 3419 3420 3421 3422 3423 3424 3425 3426 3427 3428 3429 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3404 class Snapshot < Struct.new( :accounts_with_provisioned_restore_access, :accounts_with_restore_access, :actual_incremental_backup_size_in_mega_bytes, :admin_password_secret_arn, :admin_password_secret_kms_key_id, :admin_username, :backup_progress_in_mega_bytes, :current_backup_rate_in_mega_bytes_per_second, :elapsed_time_in_seconds, :estimated_seconds_to_completion, :kms_key_id, :namespace_arn, :namespace_name, :owner_account, :snapshot_arn, :snapshot_create_time, :snapshot_name, :snapshot_remaining_days, :snapshot_retention_period, :snapshot_retention_start_time, :status, :total_backup_size_in_mega_bytes) SENSITIVE = [] include Aws::Structure end |
#actual_incremental_backup_size_in_mega_bytes ⇒ Float
The size of the incremental backup in megabytes.
3404 3405 3406 3407 3408 3409 3410 3411 3412 3413 3414 3415 3416 3417 3418 3419 3420 3421 3422 3423 3424 3425 3426 3427 3428 3429 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3404 class Snapshot < Struct.new( :accounts_with_provisioned_restore_access, :accounts_with_restore_access, :actual_incremental_backup_size_in_mega_bytes, :admin_password_secret_arn, :admin_password_secret_kms_key_id, :admin_username, :backup_progress_in_mega_bytes, :current_backup_rate_in_mega_bytes_per_second, :elapsed_time_in_seconds, :estimated_seconds_to_completion, :kms_key_id, :namespace_arn, :namespace_name, :owner_account, :snapshot_arn, :snapshot_create_time, :snapshot_name, :snapshot_remaining_days, :snapshot_retention_period, :snapshot_retention_start_time, :status, :total_backup_size_in_mega_bytes) SENSITIVE = [] include Aws::Structure end |
#admin_password_secret_arn ⇒ String
The Amazon Resource Name (ARN) for the namespace's admin user credentials secret.
3404 3405 3406 3407 3408 3409 3410 3411 3412 3413 3414 3415 3416 3417 3418 3419 3420 3421 3422 3423 3424 3425 3426 3427 3428 3429 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3404 class Snapshot < Struct.new( :accounts_with_provisioned_restore_access, :accounts_with_restore_access, :actual_incremental_backup_size_in_mega_bytes, :admin_password_secret_arn, :admin_password_secret_kms_key_id, :admin_username, :backup_progress_in_mega_bytes, :current_backup_rate_in_mega_bytes_per_second, :elapsed_time_in_seconds, :estimated_seconds_to_completion, :kms_key_id, :namespace_arn, :namespace_name, :owner_account, :snapshot_arn, :snapshot_create_time, :snapshot_name, :snapshot_remaining_days, :snapshot_retention_period, :snapshot_retention_start_time, :status, :total_backup_size_in_mega_bytes) SENSITIVE = [] include Aws::Structure end |
#admin_password_secret_kms_key_id ⇒ String
The ID of the Key Management Service (KMS) key used to encrypt and store the namespace's admin credentials secret.
3404 3405 3406 3407 3408 3409 3410 3411 3412 3413 3414 3415 3416 3417 3418 3419 3420 3421 3422 3423 3424 3425 3426 3427 3428 3429 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3404 class Snapshot < Struct.new( :accounts_with_provisioned_restore_access, :accounts_with_restore_access, :actual_incremental_backup_size_in_mega_bytes, :admin_password_secret_arn, :admin_password_secret_kms_key_id, :admin_username, :backup_progress_in_mega_bytes, :current_backup_rate_in_mega_bytes_per_second, :elapsed_time_in_seconds, :estimated_seconds_to_completion, :kms_key_id, :namespace_arn, :namespace_name, :owner_account, :snapshot_arn, :snapshot_create_time, :snapshot_name, :snapshot_remaining_days, :snapshot_retention_period, :snapshot_retention_start_time, :status, :total_backup_size_in_mega_bytes) SENSITIVE = [] include Aws::Structure end |
#admin_username ⇒ String
The username of the database within a snapshot.
3404 3405 3406 3407 3408 3409 3410 3411 3412 3413 3414 3415 3416 3417 3418 3419 3420 3421 3422 3423 3424 3425 3426 3427 3428 3429 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3404 class Snapshot < Struct.new( :accounts_with_provisioned_restore_access, :accounts_with_restore_access, :actual_incremental_backup_size_in_mega_bytes, :admin_password_secret_arn, :admin_password_secret_kms_key_id, :admin_username, :backup_progress_in_mega_bytes, :current_backup_rate_in_mega_bytes_per_second, :elapsed_time_in_seconds, :estimated_seconds_to_completion, :kms_key_id, :namespace_arn, :namespace_name, :owner_account, :snapshot_arn, :snapshot_create_time, :snapshot_name, :snapshot_remaining_days, :snapshot_retention_period, :snapshot_retention_start_time, :status, :total_backup_size_in_mega_bytes) SENSITIVE = [] include Aws::Structure end |
#backup_progress_in_mega_bytes ⇒ Float
The size in megabytes of the data that has been backed up to a snapshot.
3404 3405 3406 3407 3408 3409 3410 3411 3412 3413 3414 3415 3416 3417 3418 3419 3420 3421 3422 3423 3424 3425 3426 3427 3428 3429 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3404 class Snapshot < Struct.new( :accounts_with_provisioned_restore_access, :accounts_with_restore_access, :actual_incremental_backup_size_in_mega_bytes, :admin_password_secret_arn, :admin_password_secret_kms_key_id, :admin_username, :backup_progress_in_mega_bytes, :current_backup_rate_in_mega_bytes_per_second, :elapsed_time_in_seconds, :estimated_seconds_to_completion, :kms_key_id, :namespace_arn, :namespace_name, :owner_account, :snapshot_arn, :snapshot_create_time, :snapshot_name, :snapshot_remaining_days, :snapshot_retention_period, :snapshot_retention_start_time, :status, :total_backup_size_in_mega_bytes) SENSITIVE = [] include Aws::Structure end |
#current_backup_rate_in_mega_bytes_per_second ⇒ Float
The rate at which data is backed up into a snapshot in megabytes per second.
3404 3405 3406 3407 3408 3409 3410 3411 3412 3413 3414 3415 3416 3417 3418 3419 3420 3421 3422 3423 3424 3425 3426 3427 3428 3429 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3404 class Snapshot < Struct.new( :accounts_with_provisioned_restore_access, :accounts_with_restore_access, :actual_incremental_backup_size_in_mega_bytes, :admin_password_secret_arn, :admin_password_secret_kms_key_id, :admin_username, :backup_progress_in_mega_bytes, :current_backup_rate_in_mega_bytes_per_second, :elapsed_time_in_seconds, :estimated_seconds_to_completion, :kms_key_id, :namespace_arn, :namespace_name, :owner_account, :snapshot_arn, :snapshot_create_time, :snapshot_name, :snapshot_remaining_days, :snapshot_retention_period, :snapshot_retention_start_time, :status, :total_backup_size_in_mega_bytes) SENSITIVE = [] include Aws::Structure end |
#elapsed_time_in_seconds ⇒ Integer
The amount of time it took to back up data into a snapshot.
3404 3405 3406 3407 3408 3409 3410 3411 3412 3413 3414 3415 3416 3417 3418 3419 3420 3421 3422 3423 3424 3425 3426 3427 3428 3429 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3404 class Snapshot < Struct.new( :accounts_with_provisioned_restore_access, :accounts_with_restore_access, :actual_incremental_backup_size_in_mega_bytes, :admin_password_secret_arn, :admin_password_secret_kms_key_id, :admin_username, :backup_progress_in_mega_bytes, :current_backup_rate_in_mega_bytes_per_second, :elapsed_time_in_seconds, :estimated_seconds_to_completion, :kms_key_id, :namespace_arn, :namespace_name, :owner_account, :snapshot_arn, :snapshot_create_time, :snapshot_name, :snapshot_remaining_days, :snapshot_retention_period, :snapshot_retention_start_time, :status, :total_backup_size_in_mega_bytes) SENSITIVE = [] include Aws::Structure end |
#estimated_seconds_to_completion ⇒ Integer
The estimated amount of seconds until the snapshot completes backup.
3404 3405 3406 3407 3408 3409 3410 3411 3412 3413 3414 3415 3416 3417 3418 3419 3420 3421 3422 3423 3424 3425 3426 3427 3428 3429 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3404 class Snapshot < Struct.new( :accounts_with_provisioned_restore_access, :accounts_with_restore_access, :actual_incremental_backup_size_in_mega_bytes, :admin_password_secret_arn, :admin_password_secret_kms_key_id, :admin_username, :backup_progress_in_mega_bytes, :current_backup_rate_in_mega_bytes_per_second, :elapsed_time_in_seconds, :estimated_seconds_to_completion, :kms_key_id, :namespace_arn, :namespace_name, :owner_account, :snapshot_arn, :snapshot_create_time, :snapshot_name, :snapshot_remaining_days, :snapshot_retention_period, :snapshot_retention_start_time, :status, :total_backup_size_in_mega_bytes) SENSITIVE = [] include Aws::Structure end |
#kms_key_id ⇒ String
The unique identifier of the KMS key used to encrypt the snapshot.
3404 3405 3406 3407 3408 3409 3410 3411 3412 3413 3414 3415 3416 3417 3418 3419 3420 3421 3422 3423 3424 3425 3426 3427 3428 3429 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3404 class Snapshot < Struct.new( :accounts_with_provisioned_restore_access, :accounts_with_restore_access, :actual_incremental_backup_size_in_mega_bytes, :admin_password_secret_arn, :admin_password_secret_kms_key_id, :admin_username, :backup_progress_in_mega_bytes, :current_backup_rate_in_mega_bytes_per_second, :elapsed_time_in_seconds, :estimated_seconds_to_completion, :kms_key_id, :namespace_arn, :namespace_name, :owner_account, :snapshot_arn, :snapshot_create_time, :snapshot_name, :snapshot_remaining_days, :snapshot_retention_period, :snapshot_retention_start_time, :status, :total_backup_size_in_mega_bytes) SENSITIVE = [] include Aws::Structure end |
#namespace_arn ⇒ String
The Amazon Resource Name (ARN) of the namespace the snapshot was created from.
3404 3405 3406 3407 3408 3409 3410 3411 3412 3413 3414 3415 3416 3417 3418 3419 3420 3421 3422 3423 3424 3425 3426 3427 3428 3429 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3404 class Snapshot < Struct.new( :accounts_with_provisioned_restore_access, :accounts_with_restore_access, :actual_incremental_backup_size_in_mega_bytes, :admin_password_secret_arn, :admin_password_secret_kms_key_id, :admin_username, :backup_progress_in_mega_bytes, :current_backup_rate_in_mega_bytes_per_second, :elapsed_time_in_seconds, :estimated_seconds_to_completion, :kms_key_id, :namespace_arn, :namespace_name, :owner_account, :snapshot_arn, :snapshot_create_time, :snapshot_name, :snapshot_remaining_days, :snapshot_retention_period, :snapshot_retention_start_time, :status, :total_backup_size_in_mega_bytes) SENSITIVE = [] include Aws::Structure end |
#namespace_name ⇒ String
The name of the namepsace.
3404 3405 3406 3407 3408 3409 3410 3411 3412 3413 3414 3415 3416 3417 3418 3419 3420 3421 3422 3423 3424 3425 3426 3427 3428 3429 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3404 class Snapshot < Struct.new( :accounts_with_provisioned_restore_access, :accounts_with_restore_access, :actual_incremental_backup_size_in_mega_bytes, :admin_password_secret_arn, :admin_password_secret_kms_key_id, :admin_username, :backup_progress_in_mega_bytes, :current_backup_rate_in_mega_bytes_per_second, :elapsed_time_in_seconds, :estimated_seconds_to_completion, :kms_key_id, :namespace_arn, :namespace_name, :owner_account, :snapshot_arn, :snapshot_create_time, :snapshot_name, :snapshot_remaining_days, :snapshot_retention_period, :snapshot_retention_start_time, :status, :total_backup_size_in_mega_bytes) SENSITIVE = [] include Aws::Structure end |
#owner_account ⇒ String
The owner Amazon Web Services; account of the snapshot.
3404 3405 3406 3407 3408 3409 3410 3411 3412 3413 3414 3415 3416 3417 3418 3419 3420 3421 3422 3423 3424 3425 3426 3427 3428 3429 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3404 class Snapshot < Struct.new( :accounts_with_provisioned_restore_access, :accounts_with_restore_access, :actual_incremental_backup_size_in_mega_bytes, :admin_password_secret_arn, :admin_password_secret_kms_key_id, :admin_username, :backup_progress_in_mega_bytes, :current_backup_rate_in_mega_bytes_per_second, :elapsed_time_in_seconds, :estimated_seconds_to_completion, :kms_key_id, :namespace_arn, :namespace_name, :owner_account, :snapshot_arn, :snapshot_create_time, :snapshot_name, :snapshot_remaining_days, :snapshot_retention_period, :snapshot_retention_start_time, :status, :total_backup_size_in_mega_bytes) SENSITIVE = [] include Aws::Structure end |
#snapshot_arn ⇒ String
The Amazon Resource Name (ARN) of the snapshot.
3404 3405 3406 3407 3408 3409 3410 3411 3412 3413 3414 3415 3416 3417 3418 3419 3420 3421 3422 3423 3424 3425 3426 3427 3428 3429 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3404 class Snapshot < Struct.new( :accounts_with_provisioned_restore_access, :accounts_with_restore_access, :actual_incremental_backup_size_in_mega_bytes, :admin_password_secret_arn, :admin_password_secret_kms_key_id, :admin_username, :backup_progress_in_mega_bytes, :current_backup_rate_in_mega_bytes_per_second, :elapsed_time_in_seconds, :estimated_seconds_to_completion, :kms_key_id, :namespace_arn, :namespace_name, :owner_account, :snapshot_arn, :snapshot_create_time, :snapshot_name, :snapshot_remaining_days, :snapshot_retention_period, :snapshot_retention_start_time, :status, :total_backup_size_in_mega_bytes) SENSITIVE = [] include Aws::Structure end |
#snapshot_create_time ⇒ Time
The timestamp of when the snapshot was created.
3404 3405 3406 3407 3408 3409 3410 3411 3412 3413 3414 3415 3416 3417 3418 3419 3420 3421 3422 3423 3424 3425 3426 3427 3428 3429 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3404 class Snapshot < Struct.new( :accounts_with_provisioned_restore_access, :accounts_with_restore_access, :actual_incremental_backup_size_in_mega_bytes, :admin_password_secret_arn, :admin_password_secret_kms_key_id, :admin_username, :backup_progress_in_mega_bytes, :current_backup_rate_in_mega_bytes_per_second, :elapsed_time_in_seconds, :estimated_seconds_to_completion, :kms_key_id, :namespace_arn, :namespace_name, :owner_account, :snapshot_arn, :snapshot_create_time, :snapshot_name, :snapshot_remaining_days, :snapshot_retention_period, :snapshot_retention_start_time, :status, :total_backup_size_in_mega_bytes) SENSITIVE = [] include Aws::Structure end |
#snapshot_name ⇒ String
The name of the snapshot.
3404 3405 3406 3407 3408 3409 3410 3411 3412 3413 3414 3415 3416 3417 3418 3419 3420 3421 3422 3423 3424 3425 3426 3427 3428 3429 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3404 class Snapshot < Struct.new( :accounts_with_provisioned_restore_access, :accounts_with_restore_access, :actual_incremental_backup_size_in_mega_bytes, :admin_password_secret_arn, :admin_password_secret_kms_key_id, :admin_username, :backup_progress_in_mega_bytes, :current_backup_rate_in_mega_bytes_per_second, :elapsed_time_in_seconds, :estimated_seconds_to_completion, :kms_key_id, :namespace_arn, :namespace_name, :owner_account, :snapshot_arn, :snapshot_create_time, :snapshot_name, :snapshot_remaining_days, :snapshot_retention_period, :snapshot_retention_start_time, :status, :total_backup_size_in_mega_bytes) SENSITIVE = [] include Aws::Structure end |
#snapshot_remaining_days ⇒ Integer
The amount of days until the snapshot is deleted.
3404 3405 3406 3407 3408 3409 3410 3411 3412 3413 3414 3415 3416 3417 3418 3419 3420 3421 3422 3423 3424 3425 3426 3427 3428 3429 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3404 class Snapshot < Struct.new( :accounts_with_provisioned_restore_access, :accounts_with_restore_access, :actual_incremental_backup_size_in_mega_bytes, :admin_password_secret_arn, :admin_password_secret_kms_key_id, :admin_username, :backup_progress_in_mega_bytes, :current_backup_rate_in_mega_bytes_per_second, :elapsed_time_in_seconds, :estimated_seconds_to_completion, :kms_key_id, :namespace_arn, :namespace_name, :owner_account, :snapshot_arn, :snapshot_create_time, :snapshot_name, :snapshot_remaining_days, :snapshot_retention_period, :snapshot_retention_start_time, :status, :total_backup_size_in_mega_bytes) SENSITIVE = [] include Aws::Structure end |
#snapshot_retention_period ⇒ Integer
The period of time, in days, of how long the snapshot is retained.
3404 3405 3406 3407 3408 3409 3410 3411 3412 3413 3414 3415 3416 3417 3418 3419 3420 3421 3422 3423 3424 3425 3426 3427 3428 3429 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3404 class Snapshot < Struct.new( :accounts_with_provisioned_restore_access, :accounts_with_restore_access, :actual_incremental_backup_size_in_mega_bytes, :admin_password_secret_arn, :admin_password_secret_kms_key_id, :admin_username, :backup_progress_in_mega_bytes, :current_backup_rate_in_mega_bytes_per_second, :elapsed_time_in_seconds, :estimated_seconds_to_completion, :kms_key_id, :namespace_arn, :namespace_name, :owner_account, :snapshot_arn, :snapshot_create_time, :snapshot_name, :snapshot_remaining_days, :snapshot_retention_period, :snapshot_retention_start_time, :status, :total_backup_size_in_mega_bytes) SENSITIVE = [] include Aws::Structure end |
#snapshot_retention_start_time ⇒ Time
The timestamp of when data within the snapshot started getting retained.
3404 3405 3406 3407 3408 3409 3410 3411 3412 3413 3414 3415 3416 3417 3418 3419 3420 3421 3422 3423 3424 3425 3426 3427 3428 3429 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3404 class Snapshot < Struct.new( :accounts_with_provisioned_restore_access, :accounts_with_restore_access, :actual_incremental_backup_size_in_mega_bytes, :admin_password_secret_arn, :admin_password_secret_kms_key_id, :admin_username, :backup_progress_in_mega_bytes, :current_backup_rate_in_mega_bytes_per_second, :elapsed_time_in_seconds, :estimated_seconds_to_completion, :kms_key_id, :namespace_arn, :namespace_name, :owner_account, :snapshot_arn, :snapshot_create_time, :snapshot_name, :snapshot_remaining_days, :snapshot_retention_period, :snapshot_retention_start_time, :status, :total_backup_size_in_mega_bytes) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the snapshot.
3404 3405 3406 3407 3408 3409 3410 3411 3412 3413 3414 3415 3416 3417 3418 3419 3420 3421 3422 3423 3424 3425 3426 3427 3428 3429 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3404 class Snapshot < Struct.new( :accounts_with_provisioned_restore_access, :accounts_with_restore_access, :actual_incremental_backup_size_in_mega_bytes, :admin_password_secret_arn, :admin_password_secret_kms_key_id, :admin_username, :backup_progress_in_mega_bytes, :current_backup_rate_in_mega_bytes_per_second, :elapsed_time_in_seconds, :estimated_seconds_to_completion, :kms_key_id, :namespace_arn, :namespace_name, :owner_account, :snapshot_arn, :snapshot_create_time, :snapshot_name, :snapshot_remaining_days, :snapshot_retention_period, :snapshot_retention_start_time, :status, :total_backup_size_in_mega_bytes) SENSITIVE = [] include Aws::Structure end |
#total_backup_size_in_mega_bytes ⇒ Float
The total size, in megabytes, of how big the snapshot is.
3404 3405 3406 3407 3408 3409 3410 3411 3412 3413 3414 3415 3416 3417 3418 3419 3420 3421 3422 3423 3424 3425 3426 3427 3428 3429 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3404 class Snapshot < Struct.new( :accounts_with_provisioned_restore_access, :accounts_with_restore_access, :actual_incremental_backup_size_in_mega_bytes, :admin_password_secret_arn, :admin_password_secret_kms_key_id, :admin_username, :backup_progress_in_mega_bytes, :current_backup_rate_in_mega_bytes_per_second, :elapsed_time_in_seconds, :estimated_seconds_to_completion, :kms_key_id, :namespace_arn, :namespace_name, :owner_account, :snapshot_arn, :snapshot_create_time, :snapshot_name, :snapshot_remaining_days, :snapshot_retention_period, :snapshot_retention_start_time, :status, :total_backup_size_in_mega_bytes) SENSITIVE = [] include Aws::Structure end |