Class: Aws::RedshiftServerless::Types::UpdateNamespaceRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-redshiftserverless/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:admin_user_password, :admin_username]

Instance Attribute Summary collapse

Instance Attribute Details

#admin_password_secret_kms_key_idString

The ID of the Key Management Service (KMS) key used to encrypt and store the namespace's admin credentials secret. You can only use this parameter if manageAdminPassword is true.

Returns:

  • (String)


3972
3973
3974
3975
3976
3977
3978
3979
3980
3981
3982
3983
3984
3985
3986
3987
3988
3989
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3972

class UpdateNamespaceRequest < Struct.new(
  :admin_password_secret_kms_key_id,
  :admin_user_password,
  :admin_username,
  :default_iam_role_arn,
  :iam_roles,
  :kms_key_id,
  :log_destination_type,
  :log_exports,
  :manage_admin_password,
  :namespace_name,
  :s3_table_action,
  :s3_table_granularity,
  :s3_table_kms_key_id,
  :s3_table_names)
  SENSITIVE = [:admin_user_password, :admin_username]
  include Aws::Structure
end

#admin_user_passwordString

The password of the administrator for the first database created in the namespace. This parameter must be updated together with adminUsername.

You can't use adminUserPassword if manageAdminPassword is true.

If your admin user account is locked, this operation also unlocks your account and resets the failed-login counter. This option is available only when account lockout security is enabled for the namespace.

Returns:

  • (String)


3972
3973
3974
3975
3976
3977
3978
3979
3980
3981
3982
3983
3984
3985
3986
3987
3988
3989
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3972

class UpdateNamespaceRequest < Struct.new(
  :admin_password_secret_kms_key_id,
  :admin_user_password,
  :admin_username,
  :default_iam_role_arn,
  :iam_roles,
  :kms_key_id,
  :log_destination_type,
  :log_exports,
  :manage_admin_password,
  :namespace_name,
  :s3_table_action,
  :s3_table_granularity,
  :s3_table_kms_key_id,
  :s3_table_names)
  SENSITIVE = [:admin_user_password, :admin_username]
  include Aws::Structure
end

#admin_usernameString

The username of the administrator for the first database created in the namespace. This parameter must be updated together with adminUserPassword.

Returns:

  • (String)


3972
3973
3974
3975
3976
3977
3978
3979
3980
3981
3982
3983
3984
3985
3986
3987
3988
3989
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3972

class UpdateNamespaceRequest < Struct.new(
  :admin_password_secret_kms_key_id,
  :admin_user_password,
  :admin_username,
  :default_iam_role_arn,
  :iam_roles,
  :kms_key_id,
  :log_destination_type,
  :log_exports,
  :manage_admin_password,
  :namespace_name,
  :s3_table_action,
  :s3_table_granularity,
  :s3_table_kms_key_id,
  :s3_table_names)
  SENSITIVE = [:admin_user_password, :admin_username]
  include Aws::Structure
end

#default_iam_role_arnString

The Amazon Resource Name (ARN) of the IAM role to set as a default in the namespace. This parameter must be updated together with iamRoles.

Returns:

  • (String)


3972
3973
3974
3975
3976
3977
3978
3979
3980
3981
3982
3983
3984
3985
3986
3987
3988
3989
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3972

class UpdateNamespaceRequest < Struct.new(
  :admin_password_secret_kms_key_id,
  :admin_user_password,
  :admin_username,
  :default_iam_role_arn,
  :iam_roles,
  :kms_key_id,
  :log_destination_type,
  :log_exports,
  :manage_admin_password,
  :namespace_name,
  :s3_table_action,
  :s3_table_granularity,
  :s3_table_kms_key_id,
  :s3_table_names)
  SENSITIVE = [:admin_user_password, :admin_username]
  include Aws::Structure
end

#iam_rolesArray<String>

A list of IAM roles to associate with the namespace. This parameter must be updated together with defaultIamRoleArn.

Returns:

  • (Array<String>)


3972
3973
3974
3975
3976
3977
3978
3979
3980
3981
3982
3983
3984
3985
3986
3987
3988
3989
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3972

class UpdateNamespaceRequest < Struct.new(
  :admin_password_secret_kms_key_id,
  :admin_user_password,
  :admin_username,
  :default_iam_role_arn,
  :iam_roles,
  :kms_key_id,
  :log_destination_type,
  :log_exports,
  :manage_admin_password,
  :namespace_name,
  :s3_table_action,
  :s3_table_granularity,
  :s3_table_kms_key_id,
  :s3_table_names)
  SENSITIVE = [:admin_user_password, :admin_username]
  include Aws::Structure
end

#kms_key_idString

The ID of the Amazon Web Services Key Management Service key used to encrypt your data.

Returns:

  • (String)


3972
3973
3974
3975
3976
3977
3978
3979
3980
3981
3982
3983
3984
3985
3986
3987
3988
3989
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3972

class UpdateNamespaceRequest < Struct.new(
  :admin_password_secret_kms_key_id,
  :admin_user_password,
  :admin_username,
  :default_iam_role_arn,
  :iam_roles,
  :kms_key_id,
  :log_destination_type,
  :log_exports,
  :manage_admin_password,
  :namespace_name,
  :s3_table_action,
  :s3_table_granularity,
  :s3_table_kms_key_id,
  :s3_table_names)
  SENSITIVE = [:admin_user_password, :admin_username]
  include Aws::Structure
end

#log_destination_typeString

The destination for the log data. Valid values are s3table and cloudwatch.

Set this to s3table to manage Amazon S3 Tables system-table publishing for the namespace.

Returns:

  • (String)


3972
3973
3974
3975
3976
3977
3978
3979
3980
3981
3982
3983
3984
3985
3986
3987
3988
3989
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3972

class UpdateNamespaceRequest < Struct.new(
  :admin_password_secret_kms_key_id,
  :admin_user_password,
  :admin_username,
  :default_iam_role_arn,
  :iam_roles,
  :kms_key_id,
  :log_destination_type,
  :log_exports,
  :manage_admin_password,
  :namespace_name,
  :s3_table_action,
  :s3_table_granularity,
  :s3_table_kms_key_id,
  :s3_table_names)
  SENSITIVE = [:admin_user_password, :admin_username]
  include Aws::Structure
end

#log_exportsArray<String>

The types of logs the namespace can export. The export types are userlog, connectionlog, and useractivitylog.

Returns:

  • (Array<String>)


3972
3973
3974
3975
3976
3977
3978
3979
3980
3981
3982
3983
3984
3985
3986
3987
3988
3989
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3972

class UpdateNamespaceRequest < Struct.new(
  :admin_password_secret_kms_key_id,
  :admin_user_password,
  :admin_username,
  :default_iam_role_arn,
  :iam_roles,
  :kms_key_id,
  :log_destination_type,
  :log_exports,
  :manage_admin_password,
  :namespace_name,
  :s3_table_action,
  :s3_table_granularity,
  :s3_table_kms_key_id,
  :s3_table_names)
  SENSITIVE = [:admin_user_password, :admin_username]
  include Aws::Structure
end

#manage_admin_passwordBoolean

If true, Amazon Redshift uses Secrets Manager to manage the namespace's admin credentials. You can't use adminUserPassword if manageAdminPassword is true. If manageAdminPassword is false or not set, Amazon Redshift uses adminUserPassword for the admin user account's password.

Returns:

  • (Boolean)


3972
3973
3974
3975
3976
3977
3978
3979
3980
3981
3982
3983
3984
3985
3986
3987
3988
3989
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3972

class UpdateNamespaceRequest < Struct.new(
  :admin_password_secret_kms_key_id,
  :admin_user_password,
  :admin_username,
  :default_iam_role_arn,
  :iam_roles,
  :kms_key_id,
  :log_destination_type,
  :log_exports,
  :manage_admin_password,
  :namespace_name,
  :s3_table_action,
  :s3_table_granularity,
  :s3_table_kms_key_id,
  :s3_table_names)
  SENSITIVE = [:admin_user_password, :admin_username]
  include Aws::Structure
end

#namespace_nameString

The name of the namespace to update. You can't update the name of a namespace once it is created.

Returns:

  • (String)


3972
3973
3974
3975
3976
3977
3978
3979
3980
3981
3982
3983
3984
3985
3986
3987
3988
3989
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3972

class UpdateNamespaceRequest < Struct.new(
  :admin_password_secret_kms_key_id,
  :admin_user_password,
  :admin_username,
  :default_iam_role_arn,
  :iam_roles,
  :kms_key_id,
  :log_destination_type,
  :log_exports,
  :manage_admin_password,
  :namespace_name,
  :s3_table_action,
  :s3_table_granularity,
  :s3_table_kms_key_id,
  :s3_table_names)
  SENSITIVE = [:admin_user_password, :admin_username]
  include Aws::Structure
end

#s3_table_actionString

Whether to enable or disable Amazon S3 Tables publishing. Valid values are Enable and Disable, matched case-insensitively.

When omitted, defaults to Enable. Valid only when logDestinationType is s3table.

Returns:

  • (String)


3972
3973
3974
3975
3976
3977
3978
3979
3980
3981
3982
3983
3984
3985
3986
3987
3988
3989
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3972

class UpdateNamespaceRequest < Struct.new(
  :admin_password_secret_kms_key_id,
  :admin_user_password,
  :admin_username,
  :default_iam_role_arn,
  :iam_roles,
  :kms_key_id,
  :log_destination_type,
  :log_exports,
  :manage_admin_password,
  :namespace_name,
  :s3_table_action,
  :s3_table_granularity,
  :s3_table_kms_key_id,
  :s3_table_names)
  SENSITIVE = [:admin_user_password, :admin_username]
  include Aws::Structure
end

#s3_table_granularityString

The scope of the Amazon S3 Tables destination. Valid values are namespace and account, matched case-insensitively. namespace scopes the published tables to this namespace; account scopes them to the Amazon Web Services account.

Required when enabling. Omitting this parameter or passing a blank value fails with ValidationException. Valid only when logDestinationType is s3table.

Returns:

  • (String)


3972
3973
3974
3975
3976
3977
3978
3979
3980
3981
3982
3983
3984
3985
3986
3987
3988
3989
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3972

class UpdateNamespaceRequest < Struct.new(
  :admin_password_secret_kms_key_id,
  :admin_user_password,
  :admin_username,
  :default_iam_role_arn,
  :iam_roles,
  :kms_key_id,
  :log_destination_type,
  :log_exports,
  :manage_admin_password,
  :namespace_name,
  :s3_table_action,
  :s3_table_granularity,
  :s3_table_kms_key_id,
  :s3_table_names)
  SENSITIVE = [:admin_user_password, :admin_username]
  include Aws::Structure
end

#s3_table_kms_key_idString

The identifier of the Key Management Service key used to encrypt the published Amazon S3 Tables data. When omitted, the data is encrypted with SSE-S3 (Amazon S3 managed keys).

Valid only when logDestinationType is s3table.

Returns:

  • (String)


3972
3973
3974
3975
3976
3977
3978
3979
3980
3981
3982
3983
3984
3985
3986
3987
3988
3989
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3972

class UpdateNamespaceRequest < Struct.new(
  :admin_password_secret_kms_key_id,
  :admin_user_password,
  :admin_username,
  :default_iam_role_arn,
  :iam_roles,
  :kms_key_id,
  :log_destination_type,
  :log_exports,
  :manage_admin_password,
  :namespace_name,
  :s3_table_action,
  :s3_table_granularity,
  :s3_table_kms_key_id,
  :s3_table_names)
  SENSITIVE = [:admin_user_password, :admin_username]
  include Aws::Structure
end

#s3_table_namesArray<String>

The system tables to publish (on enable) or to stop publishing (on disable). Each value is either a system table view name that begins with sys_ or the keyword all.

Omitting this parameter, passing an empty list, or including all each select every current and future system table. Each name must be 1-128 characters, and the list can contain up to 256 names.

Valid only when logDestinationType is s3table.

Returns:

  • (Array<String>)


3972
3973
3974
3975
3976
3977
3978
3979
3980
3981
3982
3983
3984
3985
3986
3987
3988
3989
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3972

class UpdateNamespaceRequest < Struct.new(
  :admin_password_secret_kms_key_id,
  :admin_user_password,
  :admin_username,
  :default_iam_role_arn,
  :iam_roles,
  :kms_key_id,
  :log_destination_type,
  :log_exports,
  :manage_admin_password,
  :namespace_name,
  :s3_table_action,
  :s3_table_granularity,
  :s3_table_kms_key_id,
  :s3_table_names)
  SENSITIVE = [:admin_user_password, :admin_username]
  include Aws::Structure
end