Class: Aws::RedshiftServerless::Types::UpdateSnapshotCopyConfigurationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::RedshiftServerless::Types::UpdateSnapshotCopyConfigurationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-redshiftserverless/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#snapshot_copy_configuration_id ⇒ String
The ID of the snapshot copy configuration to update.
-
#snapshot_retention_period ⇒ Integer
The new retention period of how long to keep a snapshot in the destination Amazon Web Services Region.
Instance Attribute Details
#snapshot_copy_configuration_id ⇒ String
The ID of the snapshot copy configuration to update.
4006 4007 4008 4009 4010 4011 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 4006 class UpdateSnapshotCopyConfigurationRequest < Struct.new( :snapshot_copy_configuration_id, :snapshot_retention_period) SENSITIVE = [] include Aws::Structure end |
#snapshot_retention_period ⇒ Integer
The new retention period of how long to keep a snapshot in the destination Amazon Web Services Region.
4006 4007 4008 4009 4010 4011 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 4006 class UpdateSnapshotCopyConfigurationRequest < Struct.new( :snapshot_copy_configuration_id, :snapshot_retention_period) SENSITIVE = [] include Aws::Structure end |