Class: Aws::RedshiftServerless::Types::UpdateWorkgroupRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::RedshiftServerless::Types::UpdateWorkgroupRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-redshiftserverless/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#base_capacity ⇒ Integer
The new base data warehouse capacity in Redshift Processing Units (RPUs).
-
#config_parameters ⇒ Array<Types::ConfigParameter>
An array of parameters to set for advanced control over a database.
-
#enhanced_vpc_routing ⇒ Boolean
The value that specifies whether to turn on enhanced virtual private cloud (VPC) routing, which forces Amazon Redshift Serverless to route traffic through your VPC.
-
#extra_compute_for_automatic_optimization ⇒ Boolean
If
true, allocates additional compute resources for running automatic optimization operations. -
#ip_address_type ⇒ String
The IP address type that the workgroup supports.
-
#max_capacity ⇒ Integer
The maximum data-warehouse capacity Amazon Redshift Serverless uses to serve queries.
-
#port ⇒ Integer
The custom port to use when connecting to a workgroup.
-
#price_performance_target ⇒ Types::PerformanceTarget
An object that represents the price performance target settings for the workgroup.
-
#publicly_accessible ⇒ Boolean
A value that specifies whether the workgroup can be accessible from a public network.
-
#security_group_ids ⇒ Array<String>
An array of security group IDs to associate with the workgroup.
-
#subnet_ids ⇒ Array<String>
An array of VPC subnet IDs to associate with the workgroup.
-
#track_name ⇒ String
An optional parameter for the name of the track for the workgroup.
-
#workgroup_name ⇒ String
The name of the workgroup to update.
Instance Attribute Details
#base_capacity ⇒ Integer
The new base data warehouse capacity in Redshift Processing Units (RPUs).
4293 4294 4295 4296 4297 4298 4299 4300 4301 4302 4303 4304 4305 4306 4307 4308 4309 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 4293 class UpdateWorkgroupRequest < Struct.new( :base_capacity, :config_parameters, :enhanced_vpc_routing, :extra_compute_for_automatic_optimization, :ip_address_type, :max_capacity, :port, :price_performance_target, :publicly_accessible, :security_group_ids, :subnet_ids, :track_name, :workgroup_name) SENSITIVE = [] include Aws::Structure end |
#config_parameters ⇒ Array<Types::ConfigParameter>
An array of parameters to set for advanced control over a database.
The options are auto_mv, datestyle,
enable_case_sensitive_identifier, enable_user_activity_logging,
query_group, search_path, require_ssl, use_fips_ssl, and
either wlm_json_configuration or query monitoring metrics that let
you define performance boundaries. You can either specify individual
query monitoring metrics (such as max_scan_row_count,
max_query_execution_time) or use wlm_json_configuration to
define query queues with rules, but not both. If you're using
wlm_json_configuration, the maximum size of parameterValue is
8000 characters. For more information about query monitoring rules
and available metrics, see Query monitoring metrics for Amazon
Redshift Serverless.
4293 4294 4295 4296 4297 4298 4299 4300 4301 4302 4303 4304 4305 4306 4307 4308 4309 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 4293 class UpdateWorkgroupRequest < Struct.new( :base_capacity, :config_parameters, :enhanced_vpc_routing, :extra_compute_for_automatic_optimization, :ip_address_type, :max_capacity, :port, :price_performance_target, :publicly_accessible, :security_group_ids, :subnet_ids, :track_name, :workgroup_name) SENSITIVE = [] include Aws::Structure end |
#enhanced_vpc_routing ⇒ Boolean
The value that specifies whether to turn on enhanced virtual private cloud (VPC) routing, which forces Amazon Redshift Serverless to route traffic through your VPC.
4293 4294 4295 4296 4297 4298 4299 4300 4301 4302 4303 4304 4305 4306 4307 4308 4309 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 4293 class UpdateWorkgroupRequest < Struct.new( :base_capacity, :config_parameters, :enhanced_vpc_routing, :extra_compute_for_automatic_optimization, :ip_address_type, :max_capacity, :port, :price_performance_target, :publicly_accessible, :security_group_ids, :subnet_ids, :track_name, :workgroup_name) SENSITIVE = [] include Aws::Structure end |
#extra_compute_for_automatic_optimization ⇒ Boolean
If true, allocates additional compute resources for running
automatic optimization operations.
Default: false
4293 4294 4295 4296 4297 4298 4299 4300 4301 4302 4303 4304 4305 4306 4307 4308 4309 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 4293 class UpdateWorkgroupRequest < Struct.new( :base_capacity, :config_parameters, :enhanced_vpc_routing, :extra_compute_for_automatic_optimization, :ip_address_type, :max_capacity, :port, :price_performance_target, :publicly_accessible, :security_group_ids, :subnet_ids, :track_name, :workgroup_name) SENSITIVE = [] include Aws::Structure end |
#ip_address_type ⇒ String
The IP address type that the workgroup supports. Possible values are
ipv4 and dualstack.
4293 4294 4295 4296 4297 4298 4299 4300 4301 4302 4303 4304 4305 4306 4307 4308 4309 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 4293 class UpdateWorkgroupRequest < Struct.new( :base_capacity, :config_parameters, :enhanced_vpc_routing, :extra_compute_for_automatic_optimization, :ip_address_type, :max_capacity, :port, :price_performance_target, :publicly_accessible, :security_group_ids, :subnet_ids, :track_name, :workgroup_name) SENSITIVE = [] include Aws::Structure end |
#max_capacity ⇒ Integer
The maximum data-warehouse capacity Amazon Redshift Serverless uses to serve queries. The max capacity is specified in RPUs.
4293 4294 4295 4296 4297 4298 4299 4300 4301 4302 4303 4304 4305 4306 4307 4308 4309 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 4293 class UpdateWorkgroupRequest < Struct.new( :base_capacity, :config_parameters, :enhanced_vpc_routing, :extra_compute_for_automatic_optimization, :ip_address_type, :max_capacity, :port, :price_performance_target, :publicly_accessible, :security_group_ids, :subnet_ids, :track_name, :workgroup_name) SENSITIVE = [] include Aws::Structure end |
#port ⇒ Integer
The custom port to use when connecting to a workgroup. Valid port ranges are 5431-5455 and 8191-8215. The default is 5439.
4293 4294 4295 4296 4297 4298 4299 4300 4301 4302 4303 4304 4305 4306 4307 4308 4309 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 4293 class UpdateWorkgroupRequest < Struct.new( :base_capacity, :config_parameters, :enhanced_vpc_routing, :extra_compute_for_automatic_optimization, :ip_address_type, :max_capacity, :port, :price_performance_target, :publicly_accessible, :security_group_ids, :subnet_ids, :track_name, :workgroup_name) SENSITIVE = [] include Aws::Structure end |
#price_performance_target ⇒ Types::PerformanceTarget
An object that represents the price performance target settings for the workgroup.
4293 4294 4295 4296 4297 4298 4299 4300 4301 4302 4303 4304 4305 4306 4307 4308 4309 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 4293 class UpdateWorkgroupRequest < Struct.new( :base_capacity, :config_parameters, :enhanced_vpc_routing, :extra_compute_for_automatic_optimization, :ip_address_type, :max_capacity, :port, :price_performance_target, :publicly_accessible, :security_group_ids, :subnet_ids, :track_name, :workgroup_name) SENSITIVE = [] include Aws::Structure end |
#publicly_accessible ⇒ Boolean
A value that specifies whether the workgroup can be accessible from a public network.
4293 4294 4295 4296 4297 4298 4299 4300 4301 4302 4303 4304 4305 4306 4307 4308 4309 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 4293 class UpdateWorkgroupRequest < Struct.new( :base_capacity, :config_parameters, :enhanced_vpc_routing, :extra_compute_for_automatic_optimization, :ip_address_type, :max_capacity, :port, :price_performance_target, :publicly_accessible, :security_group_ids, :subnet_ids, :track_name, :workgroup_name) SENSITIVE = [] include Aws::Structure end |
#security_group_ids ⇒ Array<String>
An array of security group IDs to associate with the workgroup.
4293 4294 4295 4296 4297 4298 4299 4300 4301 4302 4303 4304 4305 4306 4307 4308 4309 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 4293 class UpdateWorkgroupRequest < Struct.new( :base_capacity, :config_parameters, :enhanced_vpc_routing, :extra_compute_for_automatic_optimization, :ip_address_type, :max_capacity, :port, :price_performance_target, :publicly_accessible, :security_group_ids, :subnet_ids, :track_name, :workgroup_name) SENSITIVE = [] include Aws::Structure end |
#subnet_ids ⇒ Array<String>
An array of VPC subnet IDs to associate with the workgroup.
4293 4294 4295 4296 4297 4298 4299 4300 4301 4302 4303 4304 4305 4306 4307 4308 4309 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 4293 class UpdateWorkgroupRequest < Struct.new( :base_capacity, :config_parameters, :enhanced_vpc_routing, :extra_compute_for_automatic_optimization, :ip_address_type, :max_capacity, :port, :price_performance_target, :publicly_accessible, :security_group_ids, :subnet_ids, :track_name, :workgroup_name) SENSITIVE = [] include Aws::Structure end |
#track_name ⇒ String
An optional parameter for the name of the track for the workgroup.
If you don't provide a track name, the workgroup is assigned to the
current track.
4293 4294 4295 4296 4297 4298 4299 4300 4301 4302 4303 4304 4305 4306 4307 4308 4309 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 4293 class UpdateWorkgroupRequest < Struct.new( :base_capacity, :config_parameters, :enhanced_vpc_routing, :extra_compute_for_automatic_optimization, :ip_address_type, :max_capacity, :port, :price_performance_target, :publicly_accessible, :security_group_ids, :subnet_ids, :track_name, :workgroup_name) SENSITIVE = [] include Aws::Structure end |
#workgroup_name ⇒ String
The name of the workgroup to update. You can't update the name of a workgroup once it is created.
4293 4294 4295 4296 4297 4298 4299 4300 4301 4302 4303 4304 4305 4306 4307 4308 4309 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 4293 class UpdateWorkgroupRequest < Struct.new( :base_capacity, :config_parameters, :enhanced_vpc_routing, :extra_compute_for_automatic_optimization, :ip_address_type, :max_capacity, :port, :price_performance_target, :publicly_accessible, :security_group_ids, :subnet_ids, :track_name, :workgroup_name) SENSITIVE = [] include Aws::Structure end |