Class: Aws::RedshiftServerless::Types::Workgroup
- Inherits:
-
Struct
- Object
- Struct
- Aws::RedshiftServerless::Types::Workgroup
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-redshiftserverless/types.rb
Overview
The collection of computing resources from which an endpoint is created.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#base_capacity ⇒ Integer
The base data warehouse capacity of the workgroup in Redshift Processing Units (RPUs).
-
#config_parameters ⇒ Array<Types::ConfigParameter>
An array of parameters to set for advanced control over a database.
-
#creation_date ⇒ Time
The creation date of the workgroup.
-
#cross_account_vpcs ⇒ Array<String>
A list of VPCs.
-
#custom_domain_certificate_arn ⇒ String
The custom domain name’s certificate Amazon resource name (ARN).
-
#custom_domain_certificate_expiry_time ⇒ Time
The expiration time for the certificate.
-
#custom_domain_name ⇒ String
The custom domain name associated with the workgroup.
-
#endpoint ⇒ Types::Endpoint
The endpoint that is created from the workgroup.
-
#enhanced_vpc_routing ⇒ Boolean
The value that specifies whether to enable enhanced virtual private cloud (VPC) routing, which forces Amazon Redshift Serverless to route traffic through your VPC.
-
#extra_compute_for_automatic_optimization ⇒ Boolean
A boolean value that, if
true, indicates that the workgroup allocates additional compute resources to run automatic optimization operations. -
#ip_address_type ⇒ String
The IP address type that the workgroup supports.
-
#max_capacity ⇒ Integer
The maximum data-warehouse capacity Amazon Redshift Serverless uses to serve queries.
-
#namespace_name ⇒ String
The namespace the workgroup is associated with.
-
#patch_version ⇒ String
The patch version of your Amazon Redshift Serverless workgroup.
-
#pending_track_name ⇒ String
The name for the track that you want to assign to the workgroup.
-
#port ⇒ Integer
The custom port to use when connecting to a workgroup.
-
#price_performance_target ⇒ Types::PerformanceTarget
An object that represents the price performance target settings for the workgroup.
-
#publicly_accessible ⇒ Boolean
A value that specifies whether the workgroup can be accessible from a public network.
-
#security_group_ids ⇒ Array<String>
An array of security group IDs to associate with the workgroup.
-
#status ⇒ String
The status of the workgroup.
-
#subnet_ids ⇒ Array<String>
An array of subnet IDs the workgroup is associated with.
-
#track_name ⇒ String
The name of the track for the workgroup.
-
#workgroup_arn ⇒ String
The Amazon Resource Name (ARN) that links to the workgroup.
-
#workgroup_id ⇒ String
The unique identifier of the workgroup.
-
#workgroup_name ⇒ String
The name of the workgroup.
-
#workgroup_version ⇒ String
The Amazon Redshift Serverless version of your workgroup.
Instance Attribute Details
#base_capacity ⇒ Integer
The base data warehouse capacity of the workgroup in Redshift Processing Units (RPUs).
4484 4485 4486 4487 4488 4489 4490 4491 4492 4493 4494 4495 4496 4497 4498 4499 4500 4501 4502 4503 4504 4505 4506 4507 4508 4509 4510 4511 4512 4513 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 4484 class Workgroup < Struct.new( :base_capacity, :config_parameters, :creation_date, :cross_account_vpcs, :custom_domain_certificate_arn, :custom_domain_certificate_expiry_time, :custom_domain_name, :endpoint, :enhanced_vpc_routing, :extra_compute_for_automatic_optimization, :ip_address_type, :max_capacity, :namespace_name, :patch_version, :pending_track_name, :port, :price_performance_target, :publicly_accessible, :security_group_ids, :status, :subnet_ids, :track_name, :workgroup_arn, :workgroup_id, :workgroup_name, :workgroup_version) SENSITIVE = [] include Aws::Structure end |
#config_parameters ⇒ Array<Types::ConfigParameter>
An array of parameters to set for advanced control over a database.
The options are auto_mv, datestyle,
enable_case_sensitive_identifier, enable_user_activity_logging,
query_group, search_path, require_ssl, use_fips_ssl, and
either wlm_json_configuration or query monitoring metrics that let
you define performance boundaries. You can either specify individual
query monitoring metrics (such as max_scan_row_count,
max_query_execution_time) or use wlm_json_configuration to
define query queues with rules, but not both. If you're using
wlm_json_configuration, the maximum size of parameterValue is
8000 characters. For more information about query monitoring rules
and available metrics, see Query monitoring metrics for Amazon
Redshift Serverless.
4484 4485 4486 4487 4488 4489 4490 4491 4492 4493 4494 4495 4496 4497 4498 4499 4500 4501 4502 4503 4504 4505 4506 4507 4508 4509 4510 4511 4512 4513 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 4484 class Workgroup < Struct.new( :base_capacity, :config_parameters, :creation_date, :cross_account_vpcs, :custom_domain_certificate_arn, :custom_domain_certificate_expiry_time, :custom_domain_name, :endpoint, :enhanced_vpc_routing, :extra_compute_for_automatic_optimization, :ip_address_type, :max_capacity, :namespace_name, :patch_version, :pending_track_name, :port, :price_performance_target, :publicly_accessible, :security_group_ids, :status, :subnet_ids, :track_name, :workgroup_arn, :workgroup_id, :workgroup_name, :workgroup_version) SENSITIVE = [] include Aws::Structure end |
#creation_date ⇒ Time
The creation date of the workgroup.
4484 4485 4486 4487 4488 4489 4490 4491 4492 4493 4494 4495 4496 4497 4498 4499 4500 4501 4502 4503 4504 4505 4506 4507 4508 4509 4510 4511 4512 4513 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 4484 class Workgroup < Struct.new( :base_capacity, :config_parameters, :creation_date, :cross_account_vpcs, :custom_domain_certificate_arn, :custom_domain_certificate_expiry_time, :custom_domain_name, :endpoint, :enhanced_vpc_routing, :extra_compute_for_automatic_optimization, :ip_address_type, :max_capacity, :namespace_name, :patch_version, :pending_track_name, :port, :price_performance_target, :publicly_accessible, :security_group_ids, :status, :subnet_ids, :track_name, :workgroup_arn, :workgroup_id, :workgroup_name, :workgroup_version) SENSITIVE = [] include Aws::Structure end |
#cross_account_vpcs ⇒ Array<String>
A list of VPCs. Each entry is the unique identifier of a virtual private cloud with access to Amazon Redshift Serverless. If all of the VPCs for the grantee are allowed, it shows an asterisk.
4484 4485 4486 4487 4488 4489 4490 4491 4492 4493 4494 4495 4496 4497 4498 4499 4500 4501 4502 4503 4504 4505 4506 4507 4508 4509 4510 4511 4512 4513 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 4484 class Workgroup < Struct.new( :base_capacity, :config_parameters, :creation_date, :cross_account_vpcs, :custom_domain_certificate_arn, :custom_domain_certificate_expiry_time, :custom_domain_name, :endpoint, :enhanced_vpc_routing, :extra_compute_for_automatic_optimization, :ip_address_type, :max_capacity, :namespace_name, :patch_version, :pending_track_name, :port, :price_performance_target, :publicly_accessible, :security_group_ids, :status, :subnet_ids, :track_name, :workgroup_arn, :workgroup_id, :workgroup_name, :workgroup_version) SENSITIVE = [] include Aws::Structure end |
#custom_domain_certificate_arn ⇒ String
The custom domain name’s certificate Amazon resource name (ARN).
4484 4485 4486 4487 4488 4489 4490 4491 4492 4493 4494 4495 4496 4497 4498 4499 4500 4501 4502 4503 4504 4505 4506 4507 4508 4509 4510 4511 4512 4513 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 4484 class Workgroup < Struct.new( :base_capacity, :config_parameters, :creation_date, :cross_account_vpcs, :custom_domain_certificate_arn, :custom_domain_certificate_expiry_time, :custom_domain_name, :endpoint, :enhanced_vpc_routing, :extra_compute_for_automatic_optimization, :ip_address_type, :max_capacity, :namespace_name, :patch_version, :pending_track_name, :port, :price_performance_target, :publicly_accessible, :security_group_ids, :status, :subnet_ids, :track_name, :workgroup_arn, :workgroup_id, :workgroup_name, :workgroup_version) SENSITIVE = [] include Aws::Structure end |
#custom_domain_certificate_expiry_time ⇒ Time
The expiration time for the certificate.
4484 4485 4486 4487 4488 4489 4490 4491 4492 4493 4494 4495 4496 4497 4498 4499 4500 4501 4502 4503 4504 4505 4506 4507 4508 4509 4510 4511 4512 4513 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 4484 class Workgroup < Struct.new( :base_capacity, :config_parameters, :creation_date, :cross_account_vpcs, :custom_domain_certificate_arn, :custom_domain_certificate_expiry_time, :custom_domain_name, :endpoint, :enhanced_vpc_routing, :extra_compute_for_automatic_optimization, :ip_address_type, :max_capacity, :namespace_name, :patch_version, :pending_track_name, :port, :price_performance_target, :publicly_accessible, :security_group_ids, :status, :subnet_ids, :track_name, :workgroup_arn, :workgroup_id, :workgroup_name, :workgroup_version) SENSITIVE = [] include Aws::Structure end |
#custom_domain_name ⇒ String
The custom domain name associated with the workgroup.
4484 4485 4486 4487 4488 4489 4490 4491 4492 4493 4494 4495 4496 4497 4498 4499 4500 4501 4502 4503 4504 4505 4506 4507 4508 4509 4510 4511 4512 4513 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 4484 class Workgroup < Struct.new( :base_capacity, :config_parameters, :creation_date, :cross_account_vpcs, :custom_domain_certificate_arn, :custom_domain_certificate_expiry_time, :custom_domain_name, :endpoint, :enhanced_vpc_routing, :extra_compute_for_automatic_optimization, :ip_address_type, :max_capacity, :namespace_name, :patch_version, :pending_track_name, :port, :price_performance_target, :publicly_accessible, :security_group_ids, :status, :subnet_ids, :track_name, :workgroup_arn, :workgroup_id, :workgroup_name, :workgroup_version) SENSITIVE = [] include Aws::Structure end |
#endpoint ⇒ Types::Endpoint
The endpoint that is created from the workgroup.
4484 4485 4486 4487 4488 4489 4490 4491 4492 4493 4494 4495 4496 4497 4498 4499 4500 4501 4502 4503 4504 4505 4506 4507 4508 4509 4510 4511 4512 4513 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 4484 class Workgroup < Struct.new( :base_capacity, :config_parameters, :creation_date, :cross_account_vpcs, :custom_domain_certificate_arn, :custom_domain_certificate_expiry_time, :custom_domain_name, :endpoint, :enhanced_vpc_routing, :extra_compute_for_automatic_optimization, :ip_address_type, :max_capacity, :namespace_name, :patch_version, :pending_track_name, :port, :price_performance_target, :publicly_accessible, :security_group_ids, :status, :subnet_ids, :track_name, :workgroup_arn, :workgroup_id, :workgroup_name, :workgroup_version) SENSITIVE = [] include Aws::Structure end |
#enhanced_vpc_routing ⇒ Boolean
The value that specifies whether to enable enhanced virtual private cloud (VPC) routing, which forces Amazon Redshift Serverless to route traffic through your VPC.
4484 4485 4486 4487 4488 4489 4490 4491 4492 4493 4494 4495 4496 4497 4498 4499 4500 4501 4502 4503 4504 4505 4506 4507 4508 4509 4510 4511 4512 4513 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 4484 class Workgroup < Struct.new( :base_capacity, :config_parameters, :creation_date, :cross_account_vpcs, :custom_domain_certificate_arn, :custom_domain_certificate_expiry_time, :custom_domain_name, :endpoint, :enhanced_vpc_routing, :extra_compute_for_automatic_optimization, :ip_address_type, :max_capacity, :namespace_name, :patch_version, :pending_track_name, :port, :price_performance_target, :publicly_accessible, :security_group_ids, :status, :subnet_ids, :track_name, :workgroup_arn, :workgroup_id, :workgroup_name, :workgroup_version) SENSITIVE = [] include Aws::Structure end |
#extra_compute_for_automatic_optimization ⇒ Boolean
A boolean value that, if true, indicates that the workgroup
allocates additional compute resources to run automatic optimization
operations.
Default: false
4484 4485 4486 4487 4488 4489 4490 4491 4492 4493 4494 4495 4496 4497 4498 4499 4500 4501 4502 4503 4504 4505 4506 4507 4508 4509 4510 4511 4512 4513 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 4484 class Workgroup < Struct.new( :base_capacity, :config_parameters, :creation_date, :cross_account_vpcs, :custom_domain_certificate_arn, :custom_domain_certificate_expiry_time, :custom_domain_name, :endpoint, :enhanced_vpc_routing, :extra_compute_for_automatic_optimization, :ip_address_type, :max_capacity, :namespace_name, :patch_version, :pending_track_name, :port, :price_performance_target, :publicly_accessible, :security_group_ids, :status, :subnet_ids, :track_name, :workgroup_arn, :workgroup_id, :workgroup_name, :workgroup_version) SENSITIVE = [] include Aws::Structure end |
#ip_address_type ⇒ String
The IP address type that the workgroup supports. Possible values are
ipv4 and dualstack.
4484 4485 4486 4487 4488 4489 4490 4491 4492 4493 4494 4495 4496 4497 4498 4499 4500 4501 4502 4503 4504 4505 4506 4507 4508 4509 4510 4511 4512 4513 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 4484 class Workgroup < Struct.new( :base_capacity, :config_parameters, :creation_date, :cross_account_vpcs, :custom_domain_certificate_arn, :custom_domain_certificate_expiry_time, :custom_domain_name, :endpoint, :enhanced_vpc_routing, :extra_compute_for_automatic_optimization, :ip_address_type, :max_capacity, :namespace_name, :patch_version, :pending_track_name, :port, :price_performance_target, :publicly_accessible, :security_group_ids, :status, :subnet_ids, :track_name, :workgroup_arn, :workgroup_id, :workgroup_name, :workgroup_version) SENSITIVE = [] include Aws::Structure end |
#max_capacity ⇒ Integer
The maximum data-warehouse capacity Amazon Redshift Serverless uses to serve queries. The max capacity is specified in RPUs.
4484 4485 4486 4487 4488 4489 4490 4491 4492 4493 4494 4495 4496 4497 4498 4499 4500 4501 4502 4503 4504 4505 4506 4507 4508 4509 4510 4511 4512 4513 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 4484 class Workgroup < Struct.new( :base_capacity, :config_parameters, :creation_date, :cross_account_vpcs, :custom_domain_certificate_arn, :custom_domain_certificate_expiry_time, :custom_domain_name, :endpoint, :enhanced_vpc_routing, :extra_compute_for_automatic_optimization, :ip_address_type, :max_capacity, :namespace_name, :patch_version, :pending_track_name, :port, :price_performance_target, :publicly_accessible, :security_group_ids, :status, :subnet_ids, :track_name, :workgroup_arn, :workgroup_id, :workgroup_name, :workgroup_version) SENSITIVE = [] include Aws::Structure end |
#namespace_name ⇒ String
The namespace the workgroup is associated with.
4484 4485 4486 4487 4488 4489 4490 4491 4492 4493 4494 4495 4496 4497 4498 4499 4500 4501 4502 4503 4504 4505 4506 4507 4508 4509 4510 4511 4512 4513 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 4484 class Workgroup < Struct.new( :base_capacity, :config_parameters, :creation_date, :cross_account_vpcs, :custom_domain_certificate_arn, :custom_domain_certificate_expiry_time, :custom_domain_name, :endpoint, :enhanced_vpc_routing, :extra_compute_for_automatic_optimization, :ip_address_type, :max_capacity, :namespace_name, :patch_version, :pending_track_name, :port, :price_performance_target, :publicly_accessible, :security_group_ids, :status, :subnet_ids, :track_name, :workgroup_arn, :workgroup_id, :workgroup_name, :workgroup_version) SENSITIVE = [] include Aws::Structure end |
#patch_version ⇒ String
The patch version of your Amazon Redshift Serverless workgroup. For more information about patch versions, see Cluster versions for Amazon Redshift.
4484 4485 4486 4487 4488 4489 4490 4491 4492 4493 4494 4495 4496 4497 4498 4499 4500 4501 4502 4503 4504 4505 4506 4507 4508 4509 4510 4511 4512 4513 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 4484 class Workgroup < Struct.new( :base_capacity, :config_parameters, :creation_date, :cross_account_vpcs, :custom_domain_certificate_arn, :custom_domain_certificate_expiry_time, :custom_domain_name, :endpoint, :enhanced_vpc_routing, :extra_compute_for_automatic_optimization, :ip_address_type, :max_capacity, :namespace_name, :patch_version, :pending_track_name, :port, :price_performance_target, :publicly_accessible, :security_group_ids, :status, :subnet_ids, :track_name, :workgroup_arn, :workgroup_id, :workgroup_name, :workgroup_version) SENSITIVE = [] include Aws::Structure end |
#pending_track_name ⇒ String
The name for the track that you want to assign to the workgroup. When the track changes, the workgroup is switched to the latest workgroup release available for the track. At this point, the track name is applied.
4484 4485 4486 4487 4488 4489 4490 4491 4492 4493 4494 4495 4496 4497 4498 4499 4500 4501 4502 4503 4504 4505 4506 4507 4508 4509 4510 4511 4512 4513 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 4484 class Workgroup < Struct.new( :base_capacity, :config_parameters, :creation_date, :cross_account_vpcs, :custom_domain_certificate_arn, :custom_domain_certificate_expiry_time, :custom_domain_name, :endpoint, :enhanced_vpc_routing, :extra_compute_for_automatic_optimization, :ip_address_type, :max_capacity, :namespace_name, :patch_version, :pending_track_name, :port, :price_performance_target, :publicly_accessible, :security_group_ids, :status, :subnet_ids, :track_name, :workgroup_arn, :workgroup_id, :workgroup_name, :workgroup_version) SENSITIVE = [] include Aws::Structure end |
#port ⇒ Integer
The custom port to use when connecting to a workgroup. Valid port ranges are 5431-5455 and 8191-8215. The default is 5439.
4484 4485 4486 4487 4488 4489 4490 4491 4492 4493 4494 4495 4496 4497 4498 4499 4500 4501 4502 4503 4504 4505 4506 4507 4508 4509 4510 4511 4512 4513 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 4484 class Workgroup < Struct.new( :base_capacity, :config_parameters, :creation_date, :cross_account_vpcs, :custom_domain_certificate_arn, :custom_domain_certificate_expiry_time, :custom_domain_name, :endpoint, :enhanced_vpc_routing, :extra_compute_for_automatic_optimization, :ip_address_type, :max_capacity, :namespace_name, :patch_version, :pending_track_name, :port, :price_performance_target, :publicly_accessible, :security_group_ids, :status, :subnet_ids, :track_name, :workgroup_arn, :workgroup_id, :workgroup_name, :workgroup_version) SENSITIVE = [] include Aws::Structure end |
#price_performance_target ⇒ Types::PerformanceTarget
An object that represents the price performance target settings for the workgroup.
4484 4485 4486 4487 4488 4489 4490 4491 4492 4493 4494 4495 4496 4497 4498 4499 4500 4501 4502 4503 4504 4505 4506 4507 4508 4509 4510 4511 4512 4513 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 4484 class Workgroup < Struct.new( :base_capacity, :config_parameters, :creation_date, :cross_account_vpcs, :custom_domain_certificate_arn, :custom_domain_certificate_expiry_time, :custom_domain_name, :endpoint, :enhanced_vpc_routing, :extra_compute_for_automatic_optimization, :ip_address_type, :max_capacity, :namespace_name, :patch_version, :pending_track_name, :port, :price_performance_target, :publicly_accessible, :security_group_ids, :status, :subnet_ids, :track_name, :workgroup_arn, :workgroup_id, :workgroup_name, :workgroup_version) SENSITIVE = [] include Aws::Structure end |
#publicly_accessible ⇒ Boolean
A value that specifies whether the workgroup can be accessible from a public network.
4484 4485 4486 4487 4488 4489 4490 4491 4492 4493 4494 4495 4496 4497 4498 4499 4500 4501 4502 4503 4504 4505 4506 4507 4508 4509 4510 4511 4512 4513 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 4484 class Workgroup < Struct.new( :base_capacity, :config_parameters, :creation_date, :cross_account_vpcs, :custom_domain_certificate_arn, :custom_domain_certificate_expiry_time, :custom_domain_name, :endpoint, :enhanced_vpc_routing, :extra_compute_for_automatic_optimization, :ip_address_type, :max_capacity, :namespace_name, :patch_version, :pending_track_name, :port, :price_performance_target, :publicly_accessible, :security_group_ids, :status, :subnet_ids, :track_name, :workgroup_arn, :workgroup_id, :workgroup_name, :workgroup_version) SENSITIVE = [] include Aws::Structure end |
#security_group_ids ⇒ Array<String>
An array of security group IDs to associate with the workgroup.
4484 4485 4486 4487 4488 4489 4490 4491 4492 4493 4494 4495 4496 4497 4498 4499 4500 4501 4502 4503 4504 4505 4506 4507 4508 4509 4510 4511 4512 4513 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 4484 class Workgroup < Struct.new( :base_capacity, :config_parameters, :creation_date, :cross_account_vpcs, :custom_domain_certificate_arn, :custom_domain_certificate_expiry_time, :custom_domain_name, :endpoint, :enhanced_vpc_routing, :extra_compute_for_automatic_optimization, :ip_address_type, :max_capacity, :namespace_name, :patch_version, :pending_track_name, :port, :price_performance_target, :publicly_accessible, :security_group_ids, :status, :subnet_ids, :track_name, :workgroup_arn, :workgroup_id, :workgroup_name, :workgroup_version) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the workgroup.
4484 4485 4486 4487 4488 4489 4490 4491 4492 4493 4494 4495 4496 4497 4498 4499 4500 4501 4502 4503 4504 4505 4506 4507 4508 4509 4510 4511 4512 4513 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 4484 class Workgroup < Struct.new( :base_capacity, :config_parameters, :creation_date, :cross_account_vpcs, :custom_domain_certificate_arn, :custom_domain_certificate_expiry_time, :custom_domain_name, :endpoint, :enhanced_vpc_routing, :extra_compute_for_automatic_optimization, :ip_address_type, :max_capacity, :namespace_name, :patch_version, :pending_track_name, :port, :price_performance_target, :publicly_accessible, :security_group_ids, :status, :subnet_ids, :track_name, :workgroup_arn, :workgroup_id, :workgroup_name, :workgroup_version) SENSITIVE = [] include Aws::Structure end |
#subnet_ids ⇒ Array<String>
An array of subnet IDs the workgroup is associated with.
4484 4485 4486 4487 4488 4489 4490 4491 4492 4493 4494 4495 4496 4497 4498 4499 4500 4501 4502 4503 4504 4505 4506 4507 4508 4509 4510 4511 4512 4513 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 4484 class Workgroup < Struct.new( :base_capacity, :config_parameters, :creation_date, :cross_account_vpcs, :custom_domain_certificate_arn, :custom_domain_certificate_expiry_time, :custom_domain_name, :endpoint, :enhanced_vpc_routing, :extra_compute_for_automatic_optimization, :ip_address_type, :max_capacity, :namespace_name, :patch_version, :pending_track_name, :port, :price_performance_target, :publicly_accessible, :security_group_ids, :status, :subnet_ids, :track_name, :workgroup_arn, :workgroup_id, :workgroup_name, :workgroup_version) SENSITIVE = [] include Aws::Structure end |
#track_name ⇒ String
The name of the track for the workgroup.
4484 4485 4486 4487 4488 4489 4490 4491 4492 4493 4494 4495 4496 4497 4498 4499 4500 4501 4502 4503 4504 4505 4506 4507 4508 4509 4510 4511 4512 4513 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 4484 class Workgroup < Struct.new( :base_capacity, :config_parameters, :creation_date, :cross_account_vpcs, :custom_domain_certificate_arn, :custom_domain_certificate_expiry_time, :custom_domain_name, :endpoint, :enhanced_vpc_routing, :extra_compute_for_automatic_optimization, :ip_address_type, :max_capacity, :namespace_name, :patch_version, :pending_track_name, :port, :price_performance_target, :publicly_accessible, :security_group_ids, :status, :subnet_ids, :track_name, :workgroup_arn, :workgroup_id, :workgroup_name, :workgroup_version) SENSITIVE = [] include Aws::Structure end |
#workgroup_arn ⇒ String
The Amazon Resource Name (ARN) that links to the workgroup.
4484 4485 4486 4487 4488 4489 4490 4491 4492 4493 4494 4495 4496 4497 4498 4499 4500 4501 4502 4503 4504 4505 4506 4507 4508 4509 4510 4511 4512 4513 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 4484 class Workgroup < Struct.new( :base_capacity, :config_parameters, :creation_date, :cross_account_vpcs, :custom_domain_certificate_arn, :custom_domain_certificate_expiry_time, :custom_domain_name, :endpoint, :enhanced_vpc_routing, :extra_compute_for_automatic_optimization, :ip_address_type, :max_capacity, :namespace_name, :patch_version, :pending_track_name, :port, :price_performance_target, :publicly_accessible, :security_group_ids, :status, :subnet_ids, :track_name, :workgroup_arn, :workgroup_id, :workgroup_name, :workgroup_version) SENSITIVE = [] include Aws::Structure end |
#workgroup_id ⇒ String
The unique identifier of the workgroup.
4484 4485 4486 4487 4488 4489 4490 4491 4492 4493 4494 4495 4496 4497 4498 4499 4500 4501 4502 4503 4504 4505 4506 4507 4508 4509 4510 4511 4512 4513 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 4484 class Workgroup < Struct.new( :base_capacity, :config_parameters, :creation_date, :cross_account_vpcs, :custom_domain_certificate_arn, :custom_domain_certificate_expiry_time, :custom_domain_name, :endpoint, :enhanced_vpc_routing, :extra_compute_for_automatic_optimization, :ip_address_type, :max_capacity, :namespace_name, :patch_version, :pending_track_name, :port, :price_performance_target, :publicly_accessible, :security_group_ids, :status, :subnet_ids, :track_name, :workgroup_arn, :workgroup_id, :workgroup_name, :workgroup_version) SENSITIVE = [] include Aws::Structure end |
#workgroup_name ⇒ String
The name of the workgroup.
4484 4485 4486 4487 4488 4489 4490 4491 4492 4493 4494 4495 4496 4497 4498 4499 4500 4501 4502 4503 4504 4505 4506 4507 4508 4509 4510 4511 4512 4513 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 4484 class Workgroup < Struct.new( :base_capacity, :config_parameters, :creation_date, :cross_account_vpcs, :custom_domain_certificate_arn, :custom_domain_certificate_expiry_time, :custom_domain_name, :endpoint, :enhanced_vpc_routing, :extra_compute_for_automatic_optimization, :ip_address_type, :max_capacity, :namespace_name, :patch_version, :pending_track_name, :port, :price_performance_target, :publicly_accessible, :security_group_ids, :status, :subnet_ids, :track_name, :workgroup_arn, :workgroup_id, :workgroup_name, :workgroup_version) SENSITIVE = [] include Aws::Structure end |
#workgroup_version ⇒ String
The Amazon Redshift Serverless version of your workgroup. For more information about Amazon Redshift Serverless versions, seeCluster versions for Amazon Redshift.
4484 4485 4486 4487 4488 4489 4490 4491 4492 4493 4494 4495 4496 4497 4498 4499 4500 4501 4502 4503 4504 4505 4506 4507 4508 4509 4510 4511 4512 4513 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 4484 class Workgroup < Struct.new( :base_capacity, :config_parameters, :creation_date, :cross_account_vpcs, :custom_domain_certificate_arn, :custom_domain_certificate_expiry_time, :custom_domain_name, :endpoint, :enhanced_vpc_routing, :extra_compute_for_automatic_optimization, :ip_address_type, :max_capacity, :namespace_name, :patch_version, :pending_track_name, :port, :price_performance_target, :publicly_accessible, :security_group_ids, :status, :subnet_ids, :track_name, :workgroup_arn, :workgroup_id, :workgroup_name, :workgroup_version) SENSITIVE = [] include Aws::Structure end |