Class: Aws::RedshiftServerless::Types::GetCredentialsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-redshiftserverless/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:db_password, :db_user]

Instance Attribute Summary collapse

Instance Attribute Details

#db_passwordString

A temporary password that authorizes the user name returned by DbUser to log on to the database DbName.

Returns:

  • (String)


1185
1186
1187
1188
1189
1190
1191
1192
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 1185

class GetCredentialsResponse < Struct.new(
  :db_password,
  :db_user,
  :expiration,
  :next_refresh_time)
  SENSITIVE = [:db_password, :db_user]
  include Aws::Structure
end

#db_userString

A database user name that is authorized to log on to the database DbName using the password DbPassword. If the specified DbUser exists in the database, the new user name has the same database privileges as the the user named in DbUser. By default, the user is added to PUBLIC.

Returns:

  • (String)


1185
1186
1187
1188
1189
1190
1191
1192
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 1185

class GetCredentialsResponse < Struct.new(
  :db_password,
  :db_user,
  :expiration,
  :next_refresh_time)
  SENSITIVE = [:db_password, :db_user]
  include Aws::Structure
end

#expirationTime

The date and time the password in DbPassword expires.

Returns:

  • (Time)


1185
1186
1187
1188
1189
1190
1191
1192
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 1185

class GetCredentialsResponse < Struct.new(
  :db_password,
  :db_user,
  :expiration,
  :next_refresh_time)
  SENSITIVE = [:db_password, :db_user]
  include Aws::Structure
end

#next_refresh_timeTime

The date and time of when the DbUser and DbPassword authorization refreshes.

Returns:

  • (Time)


1185
1186
1187
1188
1189
1190
1191
1192
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 1185

class GetCredentialsResponse < Struct.new(
  :db_password,
  :db_user,
  :expiration,
  :next_refresh_time)
  SENSITIVE = [:db_password, :db_user]
  include Aws::Structure
end