Class: Aws::RedshiftServerless::Types::ListManagedWorkgroupsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::RedshiftServerless::Types::ListManagedWorkgroupsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-redshiftserverless/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
An optional parameter that specifies the maximum number of results to return.
-
#next_token ⇒ String
If your initial ListManagedWorkgroups operation returns a nextToken, you can include the returned nextToken in following ListManagedWorkgroups operations, which returns results in the next page.
-
#source_arn ⇒ String
The Amazon Resource Name (ARN) for the managed workgroup in the Glue Data Catalog.
Instance Attribute Details
#max_results ⇒ Integer
An optional parameter that specifies the maximum number of results to return. You can use nextToken to display the next page of results.
1773 1774 1775 1776 1777 1778 1779 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 1773 class ListManagedWorkgroupsRequest < Struct.new( :max_results, :next_token, :source_arn) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If your initial ListManagedWorkgroups operation returns a nextToken, you can include the returned nextToken in following ListManagedWorkgroups operations, which returns results in the next page.
1773 1774 1775 1776 1777 1778 1779 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 1773 class ListManagedWorkgroupsRequest < Struct.new( :max_results, :next_token, :source_arn) SENSITIVE = [] include Aws::Structure end |
#source_arn ⇒ String
The Amazon Resource Name (ARN) for the managed workgroup in the Glue Data Catalog.
1773 1774 1775 1776 1777 1778 1779 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 1773 class ListManagedWorkgroupsRequest < Struct.new( :max_results, :next_token, :source_arn) SENSITIVE = [] include Aws::Structure end |