Class: Aws::RedshiftServerless::Types::ListRecoveryPointsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::RedshiftServerless::Types::ListRecoveryPointsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-redshiftserverless/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
If
nextTokenis returned, there are more results available. -
#recovery_points ⇒ Array<Types::RecoveryPoint>
The returned recovery point objects.
Instance Attribute Details
#next_token ⇒ String
If nextToken is returned, there are more results available. The value of nextToken is a unique pagination token for each page. Make the call again using the returned token to retrieve the next page.
1898 1899 1900 1901 1902 1903 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 1898 class ListRecoveryPointsResponse < Struct.new( :next_token, :recovery_points) SENSITIVE = [] include Aws::Structure end |
#recovery_points ⇒ Array<Types::RecoveryPoint>
The returned recovery point objects.
1898 1899 1900 1901 1902 1903 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 1898 class ListRecoveryPointsResponse < Struct.new( :next_token, :recovery_points) SENSITIVE = [] include Aws::Structure end |