Class: Aws::RedshiftServerless::Types::ListSnapshotsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::RedshiftServerless::Types::ListSnapshotsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-redshiftserverless/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#end_time ⇒ Time
The timestamp showing when the snapshot creation finished.
-
#max_results ⇒ Integer
An optional parameter that specifies the maximum number of results to return.
-
#namespace_arn ⇒ String
The Amazon Resource Name (ARN) of the namespace from which to list all snapshots.
-
#namespace_name ⇒ String
The namespace from which to list all snapshots.
-
#next_token ⇒ String
If
nextTokenis returned, there are more results available. -
#owner_account ⇒ String
The owner Amazon Web Services account of the snapshot.
-
#start_time ⇒ Time
The time when the creation of the snapshot was initiated.
Instance Attribute Details
#end_time ⇒ Time
The timestamp showing when the snapshot creation finished.
2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 2108 class ListSnapshotsRequest < Struct.new( :end_time, :max_results, :namespace_arn, :namespace_name, :next_token, :owner_account, :start_time) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
An optional parameter that specifies the maximum number of results to return. You can use nextToken to display the next page of results.
2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 2108 class ListSnapshotsRequest < Struct.new( :end_time, :max_results, :namespace_arn, :namespace_name, :next_token, :owner_account, :start_time) SENSITIVE = [] include Aws::Structure end |
#namespace_arn ⇒ String
The Amazon Resource Name (ARN) of the namespace from which to list all snapshots.
2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 2108 class ListSnapshotsRequest < Struct.new( :end_time, :max_results, :namespace_arn, :namespace_name, :next_token, :owner_account, :start_time) SENSITIVE = [] include Aws::Structure end |
#namespace_name ⇒ String
The namespace from which to list all snapshots.
2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 2108 class ListSnapshotsRequest < Struct.new( :end_time, :max_results, :namespace_arn, :namespace_name, :next_token, :owner_account, :start_time) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If nextToken is returned, there are more results available. The value of nextToken is a unique pagination token for each page. Make the call again using the returned token to retrieve the next page.
2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 2108 class ListSnapshotsRequest < Struct.new( :end_time, :max_results, :namespace_arn, :namespace_name, :next_token, :owner_account, :start_time) SENSITIVE = [] include Aws::Structure end |
#owner_account ⇒ String
The owner Amazon Web Services account of the snapshot.
2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 2108 class ListSnapshotsRequest < Struct.new( :end_time, :max_results, :namespace_arn, :namespace_name, :next_token, :owner_account, :start_time) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ Time
The time when the creation of the snapshot was initiated.
2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 2108 class ListSnapshotsRequest < Struct.new( :end_time, :max_results, :namespace_arn, :namespace_name, :next_token, :owner_account, :start_time) SENSITIVE = [] include Aws::Structure end |