Class: Aws::RedshiftServerless::Types::RestoreFromRecoveryPointRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::RedshiftServerless::Types::RestoreFromRecoveryPointRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-redshiftserverless/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#maintain_integration ⇒ Boolean
If
true, maintain existing data sharing, zero-ETL and S3 event integrations when restoring. -
#namespace_name ⇒ String
The name of the namespace to restore data into.
-
#recovery_point_id ⇒ String
The unique identifier of the recovery point to restore from.
-
#workgroup_name ⇒ String
The name of the workgroup used to restore data.
Instance Attribute Details
#maintain_integration ⇒ Boolean
If true, maintain existing data sharing, zero-ETL and S3 event
integrations when restoring. Otherwise, integrations will not be
maintained after the restore operation. Integrations are only
maintained when restored to the same serverless namespace.
Default: true
2798 2799 2800 2801 2802 2803 2804 2805 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 2798 class RestoreFromRecoveryPointRequest < Struct.new( :maintain_integration, :namespace_name, :recovery_point_id, :workgroup_name) SENSITIVE = [] include Aws::Structure end |
#namespace_name ⇒ String
The name of the namespace to restore data into.
2798 2799 2800 2801 2802 2803 2804 2805 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 2798 class RestoreFromRecoveryPointRequest < Struct.new( :maintain_integration, :namespace_name, :recovery_point_id, :workgroup_name) SENSITIVE = [] include Aws::Structure end |
#recovery_point_id ⇒ String
The unique identifier of the recovery point to restore from.
2798 2799 2800 2801 2802 2803 2804 2805 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 2798 class RestoreFromRecoveryPointRequest < Struct.new( :maintain_integration, :namespace_name, :recovery_point_id, :workgroup_name) SENSITIVE = [] include Aws::Structure end |
#workgroup_name ⇒ String
The name of the workgroup used to restore data.
2798 2799 2800 2801 2802 2803 2804 2805 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 2798 class RestoreFromRecoveryPointRequest < Struct.new( :maintain_integration, :namespace_name, :recovery_point_id, :workgroup_name) SENSITIVE = [] include Aws::Structure end |