Class: Aws::RedshiftServerless::Types::RestoreFromSnapshotRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::RedshiftServerless::Types::RestoreFromSnapshotRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-redshiftserverless/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#admin_password_secret_kms_key_id ⇒ String
The ID of the Key Management Service (KMS) key used to encrypt and store the namespace's admin credentials secret.
-
#maintain_integration ⇒ Boolean
If
true, maintain existing data sharing, zero-ETL and S3 event integrations when restoring. -
#manage_admin_password ⇒ Boolean
If
true, Amazon Redshift uses Secrets Manager to manage the restored snapshot's admin credentials. -
#namespace_name ⇒ String
The name of the namespace to restore the snapshot to.
-
#owner_account ⇒ String
The Amazon Web Services account that owns the snapshot.
-
#snapshot_arn ⇒ String
The Amazon Resource Name (ARN) of the snapshot to restore from.
-
#snapshot_name ⇒ String
The name of the snapshot to restore from.
-
#workgroup_name ⇒ String
The name of the workgroup used to restore the snapshot.
Instance Attribute Details
#admin_password_secret_kms_key_id ⇒ String
The ID of the Key Management Service (KMS) key used to encrypt and store the namespace's admin credentials secret.
2881 2882 2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 2881 class RestoreFromSnapshotRequest < Struct.new( :admin_password_secret_kms_key_id, :maintain_integration, :manage_admin_password, :namespace_name, :owner_account, :snapshot_arn, :snapshot_name, :workgroup_name) SENSITIVE = [] include Aws::Structure end |
#maintain_integration ⇒ Boolean
If true, maintain existing data sharing, zero-ETL and S3 event
integrations when restoring. Otherwise, integrations will not be
maintained after the restore operation. Integrations are only
maintained when restored to the same serverless namespace.
Default: true
2881 2882 2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 2881 class RestoreFromSnapshotRequest < Struct.new( :admin_password_secret_kms_key_id, :maintain_integration, :manage_admin_password, :namespace_name, :owner_account, :snapshot_arn, :snapshot_name, :workgroup_name) SENSITIVE = [] include Aws::Structure end |
#manage_admin_password ⇒ Boolean
If true, Amazon Redshift uses Secrets Manager to manage the
restored snapshot's admin credentials. If MmanageAdminPassword is
false or not set, Amazon Redshift uses the admin credentials that
the namespace or cluster had at the time the snapshot was taken.
2881 2882 2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 2881 class RestoreFromSnapshotRequest < Struct.new( :admin_password_secret_kms_key_id, :maintain_integration, :manage_admin_password, :namespace_name, :owner_account, :snapshot_arn, :snapshot_name, :workgroup_name) SENSITIVE = [] include Aws::Structure end |
#namespace_name ⇒ String
The name of the namespace to restore the snapshot to.
2881 2882 2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 2881 class RestoreFromSnapshotRequest < Struct.new( :admin_password_secret_kms_key_id, :maintain_integration, :manage_admin_password, :namespace_name, :owner_account, :snapshot_arn, :snapshot_name, :workgroup_name) SENSITIVE = [] include Aws::Structure end |
#owner_account ⇒ String
The Amazon Web Services account that owns the snapshot.
2881 2882 2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 2881 class RestoreFromSnapshotRequest < Struct.new( :admin_password_secret_kms_key_id, :maintain_integration, :manage_admin_password, :namespace_name, :owner_account, :snapshot_arn, :snapshot_name, :workgroup_name) SENSITIVE = [] include Aws::Structure end |
#snapshot_arn ⇒ String
The Amazon Resource Name (ARN) of the snapshot to restore from.
Required if restoring from a provisioned cluster to Amazon Redshift
Serverless. Must not be specified at the same time as
snapshotName.
The format of the ARN is arn:aws:redshift:<region>:<account_id>:snapshot:<cluster_identifier>/<snapshot_identifier>.
2881 2882 2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 2881 class RestoreFromSnapshotRequest < Struct.new( :admin_password_secret_kms_key_id, :maintain_integration, :manage_admin_password, :namespace_name, :owner_account, :snapshot_arn, :snapshot_name, :workgroup_name) SENSITIVE = [] include Aws::Structure end |
#snapshot_name ⇒ String
The name of the snapshot to restore from. Must not be specified at
the same time as snapshotArn.
2881 2882 2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 2881 class RestoreFromSnapshotRequest < Struct.new( :admin_password_secret_kms_key_id, :maintain_integration, :manage_admin_password, :namespace_name, :owner_account, :snapshot_arn, :snapshot_name, :workgroup_name) SENSITIVE = [] include Aws::Structure end |
#workgroup_name ⇒ String
The name of the workgroup used to restore the snapshot.
2881 2882 2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 2881 class RestoreFromSnapshotRequest < Struct.new( :admin_password_secret_kms_key_id, :maintain_integration, :manage_admin_password, :namespace_name, :owner_account, :snapshot_arn, :snapshot_name, :workgroup_name) SENSITIVE = [] include Aws::Structure end |