Class: Aws::RedshiftServerless::Types::RestoreFromSnapshotRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-redshiftserverless/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#admin_password_secret_kms_key_idString

The ID of the Key Management Service (KMS) key used to encrypt and store the namespace's admin credentials secret.

Returns:

  • (String)


2874
2875
2876
2877
2878
2879
2880
2881
2882
2883
2884
2885
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 2874

class RestoreFromSnapshotRequest < Struct.new(
  :admin_password_secret_kms_key_id,
  :maintain_integration,
  :manage_admin_password,
  :namespace_name,
  :owner_account,
  :snapshot_arn,
  :snapshot_name,
  :workgroup_name)
  SENSITIVE = []
  include Aws::Structure
end

#maintain_integrationBoolean

If true, maintain existing data sharing, zero-ETL and S3 event integrations when restoring. Otherwise, integrations will not be maintained after the restore operation. Integrations are only maintained when restored to the same serverless namespace.

Default: true

Returns:

  • (Boolean)


2874
2875
2876
2877
2878
2879
2880
2881
2882
2883
2884
2885
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 2874

class RestoreFromSnapshotRequest < Struct.new(
  :admin_password_secret_kms_key_id,
  :maintain_integration,
  :manage_admin_password,
  :namespace_name,
  :owner_account,
  :snapshot_arn,
  :snapshot_name,
  :workgroup_name)
  SENSITIVE = []
  include Aws::Structure
end

#manage_admin_passwordBoolean

If true, Amazon Redshift uses Secrets Manager to manage the restored snapshot's admin credentials. If MmanageAdminPassword is false or not set, Amazon Redshift uses the admin credentials that the namespace or cluster had at the time the snapshot was taken.

Returns:

  • (Boolean)


2874
2875
2876
2877
2878
2879
2880
2881
2882
2883
2884
2885
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 2874

class RestoreFromSnapshotRequest < Struct.new(
  :admin_password_secret_kms_key_id,
  :maintain_integration,
  :manage_admin_password,
  :namespace_name,
  :owner_account,
  :snapshot_arn,
  :snapshot_name,
  :workgroup_name)
  SENSITIVE = []
  include Aws::Structure
end

#namespace_nameString

The name of the namespace to restore the snapshot to.

Returns:

  • (String)


2874
2875
2876
2877
2878
2879
2880
2881
2882
2883
2884
2885
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 2874

class RestoreFromSnapshotRequest < Struct.new(
  :admin_password_secret_kms_key_id,
  :maintain_integration,
  :manage_admin_password,
  :namespace_name,
  :owner_account,
  :snapshot_arn,
  :snapshot_name,
  :workgroup_name)
  SENSITIVE = []
  include Aws::Structure
end

#owner_accountString

The Amazon Web Services account that owns the snapshot.

Returns:

  • (String)


2874
2875
2876
2877
2878
2879
2880
2881
2882
2883
2884
2885
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 2874

class RestoreFromSnapshotRequest < Struct.new(
  :admin_password_secret_kms_key_id,
  :maintain_integration,
  :manage_admin_password,
  :namespace_name,
  :owner_account,
  :snapshot_arn,
  :snapshot_name,
  :workgroup_name)
  SENSITIVE = []
  include Aws::Structure
end

#snapshot_arnString

The Amazon Resource Name (ARN) of the snapshot to restore from. Required if restoring from a provisioned cluster to Amazon Redshift Serverless. Must not be specified at the same time as snapshotName.

The format of the ARN is arn:aws:redshift:<region>:<account_id>:snapshot:<cluster_identifier>/<snapshot_identifier>.

Returns:

  • (String)


2874
2875
2876
2877
2878
2879
2880
2881
2882
2883
2884
2885
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 2874

class RestoreFromSnapshotRequest < Struct.new(
  :admin_password_secret_kms_key_id,
  :maintain_integration,
  :manage_admin_password,
  :namespace_name,
  :owner_account,
  :snapshot_arn,
  :snapshot_name,
  :workgroup_name)
  SENSITIVE = []
  include Aws::Structure
end

#snapshot_nameString

The name of the snapshot to restore from. Must not be specified at the same time as snapshotArn.

Returns:

  • (String)


2874
2875
2876
2877
2878
2879
2880
2881
2882
2883
2884
2885
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 2874

class RestoreFromSnapshotRequest < Struct.new(
  :admin_password_secret_kms_key_id,
  :maintain_integration,
  :manage_admin_password,
  :namespace_name,
  :owner_account,
  :snapshot_arn,
  :snapshot_name,
  :workgroup_name)
  SENSITIVE = []
  include Aws::Structure
end

#workgroup_nameString

The name of the workgroup used to restore the snapshot.

Returns:

  • (String)


2874
2875
2876
2877
2878
2879
2880
2881
2882
2883
2884
2885
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 2874

class RestoreFromSnapshotRequest < Struct.new(
  :admin_password_secret_kms_key_id,
  :maintain_integration,
  :manage_admin_password,
  :namespace_name,
  :owner_account,
  :snapshot_arn,
  :snapshot_name,
  :workgroup_name)
  SENSITIVE = []
  include Aws::Structure
end