Class: Aws::RedshiftServerless::Types::RestoreTableFromSnapshotRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::RedshiftServerless::Types::RestoreTableFromSnapshotRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-redshiftserverless/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#activate_case_sensitive_identifier ⇒ Boolean
Indicates whether name identifiers for database, schema, and table are case sensitive.
-
#namespace_name ⇒ String
The namespace of the snapshot to restore from.
-
#new_table_name ⇒ String
The name of the table to create from the restore operation.
-
#snapshot_name ⇒ String
The name of the snapshot to restore the table from.
-
#source_database_name ⇒ String
The name of the source database that contains the table being restored.
-
#source_schema_name ⇒ String
The name of the source schema that contains the table being restored.
-
#source_table_name ⇒ String
The name of the source table being restored.
-
#target_database_name ⇒ String
The name of the database to restore the table to.
-
#target_schema_name ⇒ String
The name of the schema to restore the table to.
-
#workgroup_name ⇒ String
The workgroup to restore the table to.
Instance Attribute Details
#activate_case_sensitive_identifier ⇒ Boolean
Indicates whether name identifiers for database, schema, and table are case sensitive. If true, the names are case sensitive. If false, the names are not case sensitive. The default is false.
3029 3030 3031 3032 3033 3034 3035 3036 3037 3038 3039 3040 3041 3042 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3029 class RestoreTableFromSnapshotRequest < Struct.new( :activate_case_sensitive_identifier, :namespace_name, :new_table_name, :snapshot_name, :source_database_name, :source_schema_name, :source_table_name, :target_database_name, :target_schema_name, :workgroup_name) SENSITIVE = [] include Aws::Structure end |
#namespace_name ⇒ String
The namespace of the snapshot to restore from.
3029 3030 3031 3032 3033 3034 3035 3036 3037 3038 3039 3040 3041 3042 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3029 class RestoreTableFromSnapshotRequest < Struct.new( :activate_case_sensitive_identifier, :namespace_name, :new_table_name, :snapshot_name, :source_database_name, :source_schema_name, :source_table_name, :target_database_name, :target_schema_name, :workgroup_name) SENSITIVE = [] include Aws::Structure end |
#new_table_name ⇒ String
The name of the table to create from the restore operation.
3029 3030 3031 3032 3033 3034 3035 3036 3037 3038 3039 3040 3041 3042 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3029 class RestoreTableFromSnapshotRequest < Struct.new( :activate_case_sensitive_identifier, :namespace_name, :new_table_name, :snapshot_name, :source_database_name, :source_schema_name, :source_table_name, :target_database_name, :target_schema_name, :workgroup_name) SENSITIVE = [] include Aws::Structure end |
#snapshot_name ⇒ String
The name of the snapshot to restore the table from.
3029 3030 3031 3032 3033 3034 3035 3036 3037 3038 3039 3040 3041 3042 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3029 class RestoreTableFromSnapshotRequest < Struct.new( :activate_case_sensitive_identifier, :namespace_name, :new_table_name, :snapshot_name, :source_database_name, :source_schema_name, :source_table_name, :target_database_name, :target_schema_name, :workgroup_name) SENSITIVE = [] include Aws::Structure end |
#source_database_name ⇒ String
The name of the source database that contains the table being restored.
3029 3030 3031 3032 3033 3034 3035 3036 3037 3038 3039 3040 3041 3042 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3029 class RestoreTableFromSnapshotRequest < Struct.new( :activate_case_sensitive_identifier, :namespace_name, :new_table_name, :snapshot_name, :source_database_name, :source_schema_name, :source_table_name, :target_database_name, :target_schema_name, :workgroup_name) SENSITIVE = [] include Aws::Structure end |
#source_schema_name ⇒ String
The name of the source schema that contains the table being restored.
3029 3030 3031 3032 3033 3034 3035 3036 3037 3038 3039 3040 3041 3042 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3029 class RestoreTableFromSnapshotRequest < Struct.new( :activate_case_sensitive_identifier, :namespace_name, :new_table_name, :snapshot_name, :source_database_name, :source_schema_name, :source_table_name, :target_database_name, :target_schema_name, :workgroup_name) SENSITIVE = [] include Aws::Structure end |
#source_table_name ⇒ String
The name of the source table being restored.
3029 3030 3031 3032 3033 3034 3035 3036 3037 3038 3039 3040 3041 3042 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3029 class RestoreTableFromSnapshotRequest < Struct.new( :activate_case_sensitive_identifier, :namespace_name, :new_table_name, :snapshot_name, :source_database_name, :source_schema_name, :source_table_name, :target_database_name, :target_schema_name, :workgroup_name) SENSITIVE = [] include Aws::Structure end |
#target_database_name ⇒ String
The name of the database to restore the table to.
3029 3030 3031 3032 3033 3034 3035 3036 3037 3038 3039 3040 3041 3042 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3029 class RestoreTableFromSnapshotRequest < Struct.new( :activate_case_sensitive_identifier, :namespace_name, :new_table_name, :snapshot_name, :source_database_name, :source_schema_name, :source_table_name, :target_database_name, :target_schema_name, :workgroup_name) SENSITIVE = [] include Aws::Structure end |
#target_schema_name ⇒ String
The name of the schema to restore the table to.
3029 3030 3031 3032 3033 3034 3035 3036 3037 3038 3039 3040 3041 3042 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3029 class RestoreTableFromSnapshotRequest < Struct.new( :activate_case_sensitive_identifier, :namespace_name, :new_table_name, :snapshot_name, :source_database_name, :source_schema_name, :source_table_name, :target_database_name, :target_schema_name, :workgroup_name) SENSITIVE = [] include Aws::Structure end |
#workgroup_name ⇒ String
The workgroup to restore the table to.
3029 3030 3031 3032 3033 3034 3035 3036 3037 3038 3039 3040 3041 3042 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3029 class RestoreTableFromSnapshotRequest < Struct.new( :activate_case_sensitive_identifier, :namespace_name, :new_table_name, :snapshot_name, :source_database_name, :source_schema_name, :source_table_name, :target_database_name, :target_schema_name, :workgroup_name) SENSITIVE = [] include Aws::Structure end |