Class: Aws::RedshiftServerless::Types::TableRestoreStatus
- Inherits:
-
Struct
- Object
- Struct
- Aws::RedshiftServerless::Types::TableRestoreStatus
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-redshiftserverless/types.rb
Overview
Contains information about a table restore request.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#message ⇒ String
A message that explains the returned status.
-
#namespace_name ⇒ String
The namespace of the table being restored from.
-
#new_table_name ⇒ String
The name of the table to create from the restore operation.
-
#progress_in_mega_bytes ⇒ Integer
The amount of data restored to the new table so far, in megabytes (MB).
-
#recovery_point_id ⇒ String
The ID of the recovery point being restored from.
-
#request_time ⇒ Time
The time that the table restore request was made, in Universal Coordinated Time (UTC).
-
#snapshot_name ⇒ String
The name of the snapshot being restored from.
-
#source_database_name ⇒ String
The name of the source database being restored from.
-
#source_schema_name ⇒ String
The name of the source schema being restored from.
-
#source_table_name ⇒ String
The name of the source table being restored from.
-
#status ⇒ String
A value that describes the current state of the table restore request.
-
#table_restore_request_id ⇒ String
The ID of the RestoreTableFromSnapshot request.
-
#target_database_name ⇒ String
The name of the database to restore to.
-
#target_schema_name ⇒ String
The name of the schema to restore to.
-
#total_data_in_mega_bytes ⇒ Integer
The total amount of data to restore to the new table, in megabytes (MB).
-
#workgroup_name ⇒ String
The name of the workgroup being restored from.
Instance Attribute Details
#message ⇒ String
A message that explains the returned status. For example, if the
status of the operation is FAILED, the message explains why the
operation failed.
3503 3504 3505 3506 3507 3508 3509 3510 3511 3512 3513 3514 3515 3516 3517 3518 3519 3520 3521 3522 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3503 class TableRestoreStatus < Struct.new( :message, :namespace_name, :new_table_name, :progress_in_mega_bytes, :recovery_point_id, :request_time, :snapshot_name, :source_database_name, :source_schema_name, :source_table_name, :status, :table_restore_request_id, :target_database_name, :target_schema_name, :total_data_in_mega_bytes, :workgroup_name) SENSITIVE = [] include Aws::Structure end |
#namespace_name ⇒ String
The namespace of the table being restored from.
3503 3504 3505 3506 3507 3508 3509 3510 3511 3512 3513 3514 3515 3516 3517 3518 3519 3520 3521 3522 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3503 class TableRestoreStatus < Struct.new( :message, :namespace_name, :new_table_name, :progress_in_mega_bytes, :recovery_point_id, :request_time, :snapshot_name, :source_database_name, :source_schema_name, :source_table_name, :status, :table_restore_request_id, :target_database_name, :target_schema_name, :total_data_in_mega_bytes, :workgroup_name) SENSITIVE = [] include Aws::Structure end |
#new_table_name ⇒ String
The name of the table to create from the restore operation.
3503 3504 3505 3506 3507 3508 3509 3510 3511 3512 3513 3514 3515 3516 3517 3518 3519 3520 3521 3522 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3503 class TableRestoreStatus < Struct.new( :message, :namespace_name, :new_table_name, :progress_in_mega_bytes, :recovery_point_id, :request_time, :snapshot_name, :source_database_name, :source_schema_name, :source_table_name, :status, :table_restore_request_id, :target_database_name, :target_schema_name, :total_data_in_mega_bytes, :workgroup_name) SENSITIVE = [] include Aws::Structure end |
#progress_in_mega_bytes ⇒ Integer
The amount of data restored to the new table so far, in megabytes (MB).
3503 3504 3505 3506 3507 3508 3509 3510 3511 3512 3513 3514 3515 3516 3517 3518 3519 3520 3521 3522 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3503 class TableRestoreStatus < Struct.new( :message, :namespace_name, :new_table_name, :progress_in_mega_bytes, :recovery_point_id, :request_time, :snapshot_name, :source_database_name, :source_schema_name, :source_table_name, :status, :table_restore_request_id, :target_database_name, :target_schema_name, :total_data_in_mega_bytes, :workgroup_name) SENSITIVE = [] include Aws::Structure end |
#recovery_point_id ⇒ String
The ID of the recovery point being restored from.
3503 3504 3505 3506 3507 3508 3509 3510 3511 3512 3513 3514 3515 3516 3517 3518 3519 3520 3521 3522 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3503 class TableRestoreStatus < Struct.new( :message, :namespace_name, :new_table_name, :progress_in_mega_bytes, :recovery_point_id, :request_time, :snapshot_name, :source_database_name, :source_schema_name, :source_table_name, :status, :table_restore_request_id, :target_database_name, :target_schema_name, :total_data_in_mega_bytes, :workgroup_name) SENSITIVE = [] include Aws::Structure end |
#request_time ⇒ Time
The time that the table restore request was made, in Universal Coordinated Time (UTC).
3503 3504 3505 3506 3507 3508 3509 3510 3511 3512 3513 3514 3515 3516 3517 3518 3519 3520 3521 3522 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3503 class TableRestoreStatus < Struct.new( :message, :namespace_name, :new_table_name, :progress_in_mega_bytes, :recovery_point_id, :request_time, :snapshot_name, :source_database_name, :source_schema_name, :source_table_name, :status, :table_restore_request_id, :target_database_name, :target_schema_name, :total_data_in_mega_bytes, :workgroup_name) SENSITIVE = [] include Aws::Structure end |
#snapshot_name ⇒ String
The name of the snapshot being restored from.
3503 3504 3505 3506 3507 3508 3509 3510 3511 3512 3513 3514 3515 3516 3517 3518 3519 3520 3521 3522 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3503 class TableRestoreStatus < Struct.new( :message, :namespace_name, :new_table_name, :progress_in_mega_bytes, :recovery_point_id, :request_time, :snapshot_name, :source_database_name, :source_schema_name, :source_table_name, :status, :table_restore_request_id, :target_database_name, :target_schema_name, :total_data_in_mega_bytes, :workgroup_name) SENSITIVE = [] include Aws::Structure end |
#source_database_name ⇒ String
The name of the source database being restored from.
3503 3504 3505 3506 3507 3508 3509 3510 3511 3512 3513 3514 3515 3516 3517 3518 3519 3520 3521 3522 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3503 class TableRestoreStatus < Struct.new( :message, :namespace_name, :new_table_name, :progress_in_mega_bytes, :recovery_point_id, :request_time, :snapshot_name, :source_database_name, :source_schema_name, :source_table_name, :status, :table_restore_request_id, :target_database_name, :target_schema_name, :total_data_in_mega_bytes, :workgroup_name) SENSITIVE = [] include Aws::Structure end |
#source_schema_name ⇒ String
The name of the source schema being restored from.
3503 3504 3505 3506 3507 3508 3509 3510 3511 3512 3513 3514 3515 3516 3517 3518 3519 3520 3521 3522 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3503 class TableRestoreStatus < Struct.new( :message, :namespace_name, :new_table_name, :progress_in_mega_bytes, :recovery_point_id, :request_time, :snapshot_name, :source_database_name, :source_schema_name, :source_table_name, :status, :table_restore_request_id, :target_database_name, :target_schema_name, :total_data_in_mega_bytes, :workgroup_name) SENSITIVE = [] include Aws::Structure end |
#source_table_name ⇒ String
The name of the source table being restored from.
3503 3504 3505 3506 3507 3508 3509 3510 3511 3512 3513 3514 3515 3516 3517 3518 3519 3520 3521 3522 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3503 class TableRestoreStatus < Struct.new( :message, :namespace_name, :new_table_name, :progress_in_mega_bytes, :recovery_point_id, :request_time, :snapshot_name, :source_database_name, :source_schema_name, :source_table_name, :status, :table_restore_request_id, :target_database_name, :target_schema_name, :total_data_in_mega_bytes, :workgroup_name) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
A value that describes the current state of the table restore
request. Possible values are SUCCEEDED, FAILED, CANCELED,
PENDING, and IN_PROGRESS.
3503 3504 3505 3506 3507 3508 3509 3510 3511 3512 3513 3514 3515 3516 3517 3518 3519 3520 3521 3522 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3503 class TableRestoreStatus < Struct.new( :message, :namespace_name, :new_table_name, :progress_in_mega_bytes, :recovery_point_id, :request_time, :snapshot_name, :source_database_name, :source_schema_name, :source_table_name, :status, :table_restore_request_id, :target_database_name, :target_schema_name, :total_data_in_mega_bytes, :workgroup_name) SENSITIVE = [] include Aws::Structure end |
#table_restore_request_id ⇒ String
The ID of the RestoreTableFromSnapshot request.
3503 3504 3505 3506 3507 3508 3509 3510 3511 3512 3513 3514 3515 3516 3517 3518 3519 3520 3521 3522 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3503 class TableRestoreStatus < Struct.new( :message, :namespace_name, :new_table_name, :progress_in_mega_bytes, :recovery_point_id, :request_time, :snapshot_name, :source_database_name, :source_schema_name, :source_table_name, :status, :table_restore_request_id, :target_database_name, :target_schema_name, :total_data_in_mega_bytes, :workgroup_name) SENSITIVE = [] include Aws::Structure end |
#target_database_name ⇒ String
The name of the database to restore to.
3503 3504 3505 3506 3507 3508 3509 3510 3511 3512 3513 3514 3515 3516 3517 3518 3519 3520 3521 3522 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3503 class TableRestoreStatus < Struct.new( :message, :namespace_name, :new_table_name, :progress_in_mega_bytes, :recovery_point_id, :request_time, :snapshot_name, :source_database_name, :source_schema_name, :source_table_name, :status, :table_restore_request_id, :target_database_name, :target_schema_name, :total_data_in_mega_bytes, :workgroup_name) SENSITIVE = [] include Aws::Structure end |
#target_schema_name ⇒ String
The name of the schema to restore to.
3503 3504 3505 3506 3507 3508 3509 3510 3511 3512 3513 3514 3515 3516 3517 3518 3519 3520 3521 3522 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3503 class TableRestoreStatus < Struct.new( :message, :namespace_name, :new_table_name, :progress_in_mega_bytes, :recovery_point_id, :request_time, :snapshot_name, :source_database_name, :source_schema_name, :source_table_name, :status, :table_restore_request_id, :target_database_name, :target_schema_name, :total_data_in_mega_bytes, :workgroup_name) SENSITIVE = [] include Aws::Structure end |
#total_data_in_mega_bytes ⇒ Integer
The total amount of data to restore to the new table, in megabytes (MB).
3503 3504 3505 3506 3507 3508 3509 3510 3511 3512 3513 3514 3515 3516 3517 3518 3519 3520 3521 3522 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3503 class TableRestoreStatus < Struct.new( :message, :namespace_name, :new_table_name, :progress_in_mega_bytes, :recovery_point_id, :request_time, :snapshot_name, :source_database_name, :source_schema_name, :source_table_name, :status, :table_restore_request_id, :target_database_name, :target_schema_name, :total_data_in_mega_bytes, :workgroup_name) SENSITIVE = [] include Aws::Structure end |
#workgroup_name ⇒ String
The name of the workgroup being restored from.
3503 3504 3505 3506 3507 3508 3509 3510 3511 3512 3513 3514 3515 3516 3517 3518 3519 3520 3521 3522 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3503 class TableRestoreStatus < Struct.new( :message, :namespace_name, :new_table_name, :progress_in_mega_bytes, :recovery_point_id, :request_time, :snapshot_name, :source_database_name, :source_schema_name, :source_table_name, :status, :table_restore_request_id, :target_database_name, :target_schema_name, :total_data_in_mega_bytes, :workgroup_name) SENSITIVE = [] include Aws::Structure end |