Class: Aws::RedshiftServerless::Types::UpdateNamespaceRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::RedshiftServerless::Types::UpdateNamespaceRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-redshiftserverless/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:admin_user_password, :admin_username]
Instance Attribute Summary collapse
-
#admin_password_secret_kms_key_id ⇒ String
The ID of the Key Management Service (KMS) key used to encrypt and store the namespace's admin credentials secret.
-
#admin_user_password ⇒ String
The password of the administrator for the first database created in the namespace.
-
#admin_username ⇒ String
The username of the administrator for the first database created in the namespace.
-
#default_iam_role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role to set as a default in the namespace.
-
#iam_roles ⇒ Array<String>
A list of IAM roles to associate with the namespace.
-
#kms_key_id ⇒ String
The ID of the Amazon Web Services Key Management Service key used to encrypt your data.
-
#log_destination_type ⇒ String
The destination for the log data.
-
#log_exports ⇒ Array<String>
The types of logs the namespace can export.
-
#manage_admin_password ⇒ Boolean
If
true, Amazon Redshift uses Secrets Manager to manage the namespace's admin credentials. -
#namespace_name ⇒ String
The name of the namespace to update.
-
#s3_table_action ⇒ String
Whether to enable or disable Amazon S3 Tables publishing.
-
#s3_table_granularity ⇒ String
The scope of the Amazon S3 Tables destination.
-
#s3_table_kms_key_id ⇒ String
The identifier of the Key Management Service key used to encrypt the published Amazon S3 Tables data.
-
#s3_table_names ⇒ Array<String>
The system tables to publish (on enable) or to stop publishing (on disable).
Instance Attribute Details
#admin_password_secret_kms_key_id ⇒ String
The ID of the Key Management Service (KMS) key used to encrypt and
store the namespace's admin credentials secret. You can only use
this parameter if manageAdminPassword is true.
3972 3973 3974 3975 3976 3977 3978 3979 3980 3981 3982 3983 3984 3985 3986 3987 3988 3989 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3972 class UpdateNamespaceRequest < Struct.new( :admin_password_secret_kms_key_id, :admin_user_password, :admin_username, :default_iam_role_arn, :iam_roles, :kms_key_id, :log_destination_type, :log_exports, :manage_admin_password, :namespace_name, :s3_table_action, :s3_table_granularity, :s3_table_kms_key_id, :s3_table_names) SENSITIVE = [:admin_user_password, :admin_username] include Aws::Structure end |
#admin_user_password ⇒ String
The password of the administrator for the first database created in
the namespace. This parameter must be updated together with
adminUsername.
You can't use adminUserPassword if manageAdminPassword is true.
If your admin user account is locked, this operation also unlocks your account and resets the failed-login counter. This option is available only when account lockout security is enabled for the namespace.
3972 3973 3974 3975 3976 3977 3978 3979 3980 3981 3982 3983 3984 3985 3986 3987 3988 3989 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3972 class UpdateNamespaceRequest < Struct.new( :admin_password_secret_kms_key_id, :admin_user_password, :admin_username, :default_iam_role_arn, :iam_roles, :kms_key_id, :log_destination_type, :log_exports, :manage_admin_password, :namespace_name, :s3_table_action, :s3_table_granularity, :s3_table_kms_key_id, :s3_table_names) SENSITIVE = [:admin_user_password, :admin_username] include Aws::Structure end |
#admin_username ⇒ String
The username of the administrator for the first database created in
the namespace. This parameter must be updated together with
adminUserPassword.
3972 3973 3974 3975 3976 3977 3978 3979 3980 3981 3982 3983 3984 3985 3986 3987 3988 3989 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3972 class UpdateNamespaceRequest < Struct.new( :admin_password_secret_kms_key_id, :admin_user_password, :admin_username, :default_iam_role_arn, :iam_roles, :kms_key_id, :log_destination_type, :log_exports, :manage_admin_password, :namespace_name, :s3_table_action, :s3_table_granularity, :s3_table_kms_key_id, :s3_table_names) SENSITIVE = [:admin_user_password, :admin_username] include Aws::Structure end |
#default_iam_role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role to set as a default
in the namespace. This parameter must be updated together with
iamRoles.
3972 3973 3974 3975 3976 3977 3978 3979 3980 3981 3982 3983 3984 3985 3986 3987 3988 3989 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3972 class UpdateNamespaceRequest < Struct.new( :admin_password_secret_kms_key_id, :admin_user_password, :admin_username, :default_iam_role_arn, :iam_roles, :kms_key_id, :log_destination_type, :log_exports, :manage_admin_password, :namespace_name, :s3_table_action, :s3_table_granularity, :s3_table_kms_key_id, :s3_table_names) SENSITIVE = [:admin_user_password, :admin_username] include Aws::Structure end |
#iam_roles ⇒ Array<String>
A list of IAM roles to associate with the namespace. This parameter
must be updated together with defaultIamRoleArn.
3972 3973 3974 3975 3976 3977 3978 3979 3980 3981 3982 3983 3984 3985 3986 3987 3988 3989 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3972 class UpdateNamespaceRequest < Struct.new( :admin_password_secret_kms_key_id, :admin_user_password, :admin_username, :default_iam_role_arn, :iam_roles, :kms_key_id, :log_destination_type, :log_exports, :manage_admin_password, :namespace_name, :s3_table_action, :s3_table_granularity, :s3_table_kms_key_id, :s3_table_names) SENSITIVE = [:admin_user_password, :admin_username] include Aws::Structure end |
#kms_key_id ⇒ String
The ID of the Amazon Web Services Key Management Service key used to encrypt your data.
3972 3973 3974 3975 3976 3977 3978 3979 3980 3981 3982 3983 3984 3985 3986 3987 3988 3989 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3972 class UpdateNamespaceRequest < Struct.new( :admin_password_secret_kms_key_id, :admin_user_password, :admin_username, :default_iam_role_arn, :iam_roles, :kms_key_id, :log_destination_type, :log_exports, :manage_admin_password, :namespace_name, :s3_table_action, :s3_table_granularity, :s3_table_kms_key_id, :s3_table_names) SENSITIVE = [:admin_user_password, :admin_username] include Aws::Structure end |
#log_destination_type ⇒ String
The destination for the log data. Valid values are s3table and
cloudwatch.
Set this to s3table to manage Amazon S3 Tables system-table
publishing for the namespace.
3972 3973 3974 3975 3976 3977 3978 3979 3980 3981 3982 3983 3984 3985 3986 3987 3988 3989 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3972 class UpdateNamespaceRequest < Struct.new( :admin_password_secret_kms_key_id, :admin_user_password, :admin_username, :default_iam_role_arn, :iam_roles, :kms_key_id, :log_destination_type, :log_exports, :manage_admin_password, :namespace_name, :s3_table_action, :s3_table_granularity, :s3_table_kms_key_id, :s3_table_names) SENSITIVE = [:admin_user_password, :admin_username] include Aws::Structure end |
#log_exports ⇒ Array<String>
The types of logs the namespace can export. The export types are
userlog, connectionlog, and useractivitylog.
3972 3973 3974 3975 3976 3977 3978 3979 3980 3981 3982 3983 3984 3985 3986 3987 3988 3989 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3972 class UpdateNamespaceRequest < Struct.new( :admin_password_secret_kms_key_id, :admin_user_password, :admin_username, :default_iam_role_arn, :iam_roles, :kms_key_id, :log_destination_type, :log_exports, :manage_admin_password, :namespace_name, :s3_table_action, :s3_table_granularity, :s3_table_kms_key_id, :s3_table_names) SENSITIVE = [:admin_user_password, :admin_username] include Aws::Structure end |
#manage_admin_password ⇒ Boolean
If true, Amazon Redshift uses Secrets Manager to manage the
namespace's admin credentials. You can't use adminUserPassword
if manageAdminPassword is true. If manageAdminPassword is false
or not set, Amazon Redshift uses adminUserPassword for the admin
user account's password.
3972 3973 3974 3975 3976 3977 3978 3979 3980 3981 3982 3983 3984 3985 3986 3987 3988 3989 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3972 class UpdateNamespaceRequest < Struct.new( :admin_password_secret_kms_key_id, :admin_user_password, :admin_username, :default_iam_role_arn, :iam_roles, :kms_key_id, :log_destination_type, :log_exports, :manage_admin_password, :namespace_name, :s3_table_action, :s3_table_granularity, :s3_table_kms_key_id, :s3_table_names) SENSITIVE = [:admin_user_password, :admin_username] include Aws::Structure end |
#namespace_name ⇒ String
The name of the namespace to update. You can't update the name of a namespace once it is created.
3972 3973 3974 3975 3976 3977 3978 3979 3980 3981 3982 3983 3984 3985 3986 3987 3988 3989 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3972 class UpdateNamespaceRequest < Struct.new( :admin_password_secret_kms_key_id, :admin_user_password, :admin_username, :default_iam_role_arn, :iam_roles, :kms_key_id, :log_destination_type, :log_exports, :manage_admin_password, :namespace_name, :s3_table_action, :s3_table_granularity, :s3_table_kms_key_id, :s3_table_names) SENSITIVE = [:admin_user_password, :admin_username] include Aws::Structure end |
#s3_table_action ⇒ String
Whether to enable or disable Amazon S3 Tables publishing. Valid
values are Enable and Disable, matched case-insensitively.
When omitted, defaults to Enable. Valid only when
logDestinationType is s3table.
3972 3973 3974 3975 3976 3977 3978 3979 3980 3981 3982 3983 3984 3985 3986 3987 3988 3989 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3972 class UpdateNamespaceRequest < Struct.new( :admin_password_secret_kms_key_id, :admin_user_password, :admin_username, :default_iam_role_arn, :iam_roles, :kms_key_id, :log_destination_type, :log_exports, :manage_admin_password, :namespace_name, :s3_table_action, :s3_table_granularity, :s3_table_kms_key_id, :s3_table_names) SENSITIVE = [:admin_user_password, :admin_username] include Aws::Structure end |
#s3_table_granularity ⇒ String
The scope of the Amazon S3 Tables destination. Valid values are
namespace and account, matched case-insensitively. namespace
scopes the published tables to this namespace; account scopes them
to the Amazon Web Services account.
Required when enabling. Omitting this parameter or passing a blank
value fails with ValidationException. Valid only when
logDestinationType is s3table.
3972 3973 3974 3975 3976 3977 3978 3979 3980 3981 3982 3983 3984 3985 3986 3987 3988 3989 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3972 class UpdateNamespaceRequest < Struct.new( :admin_password_secret_kms_key_id, :admin_user_password, :admin_username, :default_iam_role_arn, :iam_roles, :kms_key_id, :log_destination_type, :log_exports, :manage_admin_password, :namespace_name, :s3_table_action, :s3_table_granularity, :s3_table_kms_key_id, :s3_table_names) SENSITIVE = [:admin_user_password, :admin_username] include Aws::Structure end |
#s3_table_kms_key_id ⇒ String
The identifier of the Key Management Service key used to encrypt the published Amazon S3 Tables data. When omitted, the data is encrypted with SSE-S3 (Amazon S3 managed keys).
Valid only when logDestinationType is s3table.
3972 3973 3974 3975 3976 3977 3978 3979 3980 3981 3982 3983 3984 3985 3986 3987 3988 3989 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3972 class UpdateNamespaceRequest < Struct.new( :admin_password_secret_kms_key_id, :admin_user_password, :admin_username, :default_iam_role_arn, :iam_roles, :kms_key_id, :log_destination_type, :log_exports, :manage_admin_password, :namespace_name, :s3_table_action, :s3_table_granularity, :s3_table_kms_key_id, :s3_table_names) SENSITIVE = [:admin_user_password, :admin_username] include Aws::Structure end |
#s3_table_names ⇒ Array<String>
The system tables to publish (on enable) or to stop publishing (on
disable). Each value is either a system table view name that begins
with sys_ or the keyword all.
Omitting this parameter, passing an empty list, or including all
each select every current and future system table. Each name must be
1-128 characters, and the list can contain up to 256 names.
Valid only when logDestinationType is s3table.
3972 3973 3974 3975 3976 3977 3978 3979 3980 3981 3982 3983 3984 3985 3986 3987 3988 3989 |
# File 'lib/aws-sdk-redshiftserverless/types.rb', line 3972 class UpdateNamespaceRequest < Struct.new( :admin_password_secret_kms_key_id, :admin_user_password, :admin_username, :default_iam_role_arn, :iam_roles, :kms_key_id, :log_destination_type, :log_exports, :manage_admin_password, :namespace_name, :s3_table_action, :s3_table_granularity, :s3_table_kms_key_id, :s3_table_names) SENSITIVE = [:admin_user_password, :admin_username] include Aws::Structure end |